@@ -1,4 +1,4 @@
-# $Id: About.rb,v 1.3 2004/10/14 15:43:45 toki Exp $
+# $Id: About.rb,v 1.4 2004/11/29 15:51:32 toki Exp $
 
 require 'time'
 require 'forwardable'
@@ -12,18 +12,18 @@ class About < WPM::PageContext
   end
 
   def_delegator :@control, :start_time
-  def_delegator :@control, :restart_count
   def_delegator :@control, :restart_time
+  def_delegator :@control, :restart_count
 
   def restarted?
     @control.restart_count > 0
   end
 
-  def run_time
+  def uptime
     Time.now - @control.start_time
   end
 
-  def restarted_run_time
+  def restarted_uptime
     Time.now - @control.restart_time
   end
 
