@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: AdminPassword.rb,v 1.2 2004/09/15 15:08:25 toki Exp $
+# $Id: AdminPassword.rb,v 1.3 2004/11/30 17:16:29 toki Exp $
 
 require 'forwardable'
 
@@ -16,10 +16,10 @@ class AdminPassword < WPM::PageContext
     @retype_password = nil
   end
 
-  def_delegator(:@admin_params, :modified_count)
-  def_delegator(:@admin_params, :modified_count=)
-  def_delegator(:@admin_params, :admin_user, :username)
-  def_delegator(:@admin_params, :admin_user=, :username=)
+  def_delegator :@admin_params, :modified_count
+  def_delegator :@admin_params, :modified_count=
+  def_delegator :@admin_params, :admin_user, :username
+  def_delegator :@admin_params, :admin_user=, :username=
 
   attr_writer :old_password
   attr_writer :new_password
