@@ -1,4 +1,4 @@
-# $Id: Administrator.rb,v 1.5 2004/09/15 15:10:37 toki Exp $
+# $Id: Administrator.rb,v 1.6 2004/11/30 16:55:34 toki Exp $
 
 require 'forwardable'
 
@@ -11,14 +11,14 @@ class Administrator < WPM::PageContext
     @admin_params = @control.admin_params
   end
 
-  def_delegator(:@admin_params, :modified_count)
-  def_delegator(:@admin_params, :modified_count=)
-  def_delegator(:@admin_params, :admin_user, :username)
-  def_delegator(:@admin_params, :admin_password, :password)
-  def_delegator(:@admin_params, :localhost_only)
-  def_delegator(:@admin_params, :localhost_only=)
-  def_delegator(:@admin_params, :japanese_handling)
-  def_delegator(:@admin_params, :japanese_handling=)
+  def_delegator :@admin_params, :modified_count
+  def_delegator :@admin_params, :modified_count=
+  def_delegator :@admin_params, :admin_user, :username
+  def_delegator :@admin_params, :admin_password, :password
+  def_delegator :@admin_params, :localhost_only
+  def_delegator :@admin_params, :localhost_only=
+  def_delegator :@admin_params, :japanese_handling
+  def_delegator :@admin_params, :japanese_handling=
 
   def empty_password?
     password = @admin_params.admin_password
