@@ -1,7 +1,8 @@
-# $Id: document.rb,v 1.10 2004/10/02 00:41:41 toki Exp $
+# $Id: document.rb,v 1.12 2004/11/25 05:37:53 toki Exp $
 
 require 'time'
 require 'delegate'
+require 'singleton'
 require 'rucy/error'
 require 'rucy/request'
 require 'rucy/response'
@@ -27,6 +28,14 @@ module Rucy
       # hook for subclasses.
     end
 
+    def self.doc_name
+      raise NotImplementedError, 'abstract'
+    end
+
+    def self.doc_args
+      raise NotImplementedError, 'abstract'
+    end
+
     def open
       # hook for subclasses.
     end
@@ -145,7 +154,7 @@ module Rucy
     end
 
     def publish(script_name, request, response, logger)
-      logger.debug("[#{Time.now.httpdate}] enter filter: #{@filter.class}")
+      logger.debug("enter filter: #{@filter.class}")
       context = Hash.new
       catch(:end_of_filter) {
 	begin
@@ -161,6 +170,46 @@ module Rucy
     end
   end
 
+  class DocumentBuilder
+    include Singleton
+
+    def set_doc_option(option)
+      # hook for subclasses.
+    end
+
+    def doc_name
+      raise NotImplementedError, 'abstract'
+    end
+
+    def doc_args
+      raise NotImplementedError, 'abstract'
+    end
+
+    def new(*args)
+      raise NotImplementedError, 'abstract'
+    end
+  end
+
+  class FilterBuilder
+    include Singleton
+
+    def set_filter_option(option)
+      # hook for subclasses.
+    end
+
+    def filter_name
+      raise NotImplementedError, 'abstract'
+    end
+
+    def filter_args
+      raise NotImplementedError, 'abstract'
+    end
+
+    def new(*args)
+      raise NotImplementedError, 'abstract'
+    end
+  end
+
   class DocumentFactory
     def initialize
       @option = Hash.new
@@ -256,7 +305,7 @@ module Rucy
       @factory = DocumentFactory.new
       rucy_consts = Hash[*Rucy.constants.map{|n| [n, true] }.flatten]
       Dir.foreach(@mod_path) do |rb_name|
-	path = "#{@mod_path}/#{rb_name}"
+	path = File.join(@mod_path, rb_name)
 	if ((File.file? path) && rb_name =~ /\.rb$/) then
 	  loader = SimpleLoader.new
 	  begin
@@ -266,17 +315,17 @@ module Rucy
 	      case (const_name)
 	      when /Document$/
 		@doc_map[const_name] = loader
-		doc_factory = const_name + 'Factory'
-		if (loader.const_defined? doc_factory) then
-		  @factory.add_document(loader.const_get(doc_factory).instance)
+		doc_builder = const_name + 'Builder'
+		if (loader.const_defined? doc_builder) then
+		  @factory.add_document(loader.const_get(doc_builder).instance)
 		else
 		  @factory.add_document(loader.const_get(const_name))
 		end
 	      when /Filter$/
 		@filter_map[const_name] = loader
-		filter_factory = const_name + 'Factory'
-		if (loader.const_defined? filter_factory) then
-		  @factory.add_filter(loader.const_get(filter_factory).instance)
+		filter_builder = const_name + 'Builder'
+		if (loader.const_defined? filter_builder) then
+		  @factory.add_filter(loader.const_get(filter_builder).instance)
 		else
 		  @factory.add_filter(loader.const_get(const_name))
 		end
@@ -337,7 +386,7 @@ module Rucy
     end
 
     def publish(script_name, request, response, logger)
-      logger.debug("[#{Time.now.httpdate}] enter document: #{self.class}")
+      logger.debug("enter document: #{self.class}")
       case (request.method)
       when 'GET', 'HEAD'
 	response.status = 200
@@ -649,7 +698,7 @@ module Rucy
 	  document, mount_path = doc_pair
 	  document.publish(script_name2 + mount_path, request, response, logger)
 	else
-	  logger.debug("[#{Time.now.httpdate}] not virtual mounted: http://#{host}#{request.path}")
+	  logger.debug("not virtual mounted: http://#{host}#{request.path}")
 	  raise HTTPError.new(404) # Not Found
 	end
       else
@@ -661,7 +710,7 @@ module Rucy
 	  document, mount_path = doc_pair
 	  document.publish(script_name2 + mount_path, request, response, logger)
 	else
-	  logger.debug("[#{Time.now.httpdate}] not mounted: #{request.path}")
+	  logger.debug("not mounted: #{request.path}")
 	  raise HTTPError.new(404) # Not Found
 	end
       end
