@@ -1,4 +1,4 @@
-# $Id: logger.rb,v 1.20 2004/10/03 12:43:49 toki Exp $
+# $Id: logger.rb,v 1.22 2004/12/05 01:26:30 toki Exp $
 
 require 'time'
 require 'thread'
@@ -118,7 +118,7 @@ module Rucy
 
   class AccessLog
     def self.format(messg, request, response, curr_time)
-      messg.gsub(/%{.*?}[io]|%./) { |fmt|
+      messg.gsub(/%\{.*?\}[io]|%./) {|fmt|
 	case (fmt)
 	when '%%'		# escape
 	  '%'
@@ -162,10 +162,10 @@ module Rucy
 	  request.path
 	when '%v'		# server name
 	  request.host
-	when /^%{.*}i$/	# input header
+	when /^%\{.*\}i$/	# input header
 	  name = $&[2...-2]
 	  request.header(name) || '-'
-	when /^%{.*}o$/		# output header
+	when /^%\{.*\}o$/	# output header
 	  name = $&[2...-2]
 	  response.header(name) || '-'
 	else
