@@ -1,8 +1,9 @@
-# $Id: messenger.rb,v 1.9 2004/10/17 15:17:58 toki Exp $
+# $Id: messenger.rb,v 1.13 2004/12/11 14:32:39 toki Exp $
 
 require 'time'
 require 'thread'
 require 'rucy/wait'
+require 'rucy/priv'
 require 'rucy/writer'
 require 'rucy/error'
 require 'rucy/request'
@@ -326,13 +327,13 @@ module Rucy
 
       messenger_list.each do |messenger|
 	thread = Thread.new{
-	  logger.info("[#{Time.now.httpdate}] start #{factory} thread.")
+	  logger.info("start #{factory} thread.")
 	  begin
 	    messenger.accept(socket_queue)
 	  rescue StandardError, ScriptError
-	    logger.warning("[#{Time.now.httpdate}] aborted #{factory} thread: #{$!.message} (#{$!.class}): #{$!.backtrace[0]}")
+	    logger.warning("aborted #{factory} thread: #{$!.message} (#{$!.class}): #{$!.backtrace[0]}")
 	  ensure
-	    logger.info("[#{Time.now.httpdate}] stop #{factory} thread.")
+	    logger.info("stop #{factory} thread.")
 	  end
 	}
 	messenger_thgrp.add(thread)
@@ -366,16 +367,13 @@ module Rucy
     RECV_IO = 'R'
     CLOSE   = 'C'
 
-    attr_accessor :messenger_threads
-    attr_accessor :messenger_queue_length
-    attr_accessor :subprocess_user
-    attr_accessor :subprocess_group
+    attr_reader :messenger_threads
+    attr_reader :messenger_queue_length
 
     def open(server)
       @messenger_threads = server.messenger_threads
       @messenger_queue_length = server.messenger_queue_length
-      @subprocess_user = server.subprocess_user
-      @subprocess_group = server.subprocess_group
+      @privilege = server.privilege
 
       @child_socket, @parent_socket = UNIXSocket.socketpair
       if (@pid = fork) then
@@ -410,29 +408,9 @@ module Rucy
     end
 
     def child_process
-      if (Process.euid == 0 && (@subprocess_user || @subprocess_group)) then
+      if (@privilege.privileged_user?) then
 	begin
-	  require 'etc'
-	  if (@subprocess_group) then
-	    case (@subprocess_group)
-	    when Numeric
-	      gid = @subprocess_group
-	    else
-	      gid = Etc.getgrnam(@subprocess_group).gid
-	    end
-	    Process.gid = gid
-	    Process.egid = gid
-	  end
-	  if (@subprocess_user) then
-	    case (@subprocess_user)
-	    when Numeric
-	      uid = @subprocess_user
-	    else
-	      uid = Etc.getpwnam(@subprocess_user).uid
-	    end
-	    Process.uid = uid
-	    Process.euid = uid
-	  end
+	  @privilege.cancel_privilege
 	rescue
 	  @logger.err("error: failed to change subprocess privilege: #{$!.message} (#{$!.class}): #{$!.backtrace[0]}")
 	end
