@@ -1,4 +1,4 @@
-# $Id: server.rb,v 1.9 2004/10/12 15:49:34 toki Exp $
+# $Id: server.rb,v 1.13 2004/12/11 15:50:44 toki Exp $
 
 require 'time'
 require 'socket'
@@ -109,8 +109,7 @@ module Rucy
       @messenger_factory = MultiThreadMessenger
       @messenger_threads = Messenger::MESSENGER_THREADS
       @messenger_queue_length = Messenger::MESSENGER_QUEUE_LENGTH
-      @subprocess_user = nil
-      @subprocess_group = nil
+      @privilege = nil
       nil
     end
     private :reset
@@ -143,8 +142,7 @@ module Rucy
     attr_accessor :messenger_factory
     attr_accessor :messenger_threads
     attr_accessor :messenger_queue_length
-    attr_accessor :subprocess_user
-    attr_accessor :subprocess_group
+    attr_accessor :privilege
 
     def add_filter(filter)
       @document = FilterDocument.new(@document, filter)
@@ -187,7 +185,7 @@ module Rucy
 	begin
 	  document.open
 	rescue StandardError, ScriptError
-	  logger.warning("[#{Time.now.httpdate}] failed to open a document: #{$!.message} (#{$!.class}): #{$!.backtrace[0]}")
+	  @logger.warning("failed to open a document: #{$!.message} (#{$!.class}): #{$!.backtrace[0]}")
 	end
       end
       nil
@@ -199,7 +197,7 @@ module Rucy
 	begin
 	  document.close
 	rescue StandardError, ScriptError
-	  logger.warning("[#{Time.now.httpdate}] failed to close a document: #{$!.message} (#{$!.class}): #{$!.backtrace[0]}")
+	  @logger.warning("failed to close a document: #{$!.message} (#{$!.class}): #{$!.backtrace[0]}")
 	end
       end
       nil
