@@ -1,4 +1,4 @@
-# $Id: control.rb,v 1.35 2004/10/20 14:51:50 toki Exp $
+# $Id: control.rb,v 1.37 2004/12/11 16:25:38 toki Exp $
 
 require 'forwardable'
 require 'rucy/params'
@@ -9,6 +9,7 @@ module Rucy
 
     def initialize
       @loader = nil
+      @factory = nil
       @pw_enc = PasswordEncryptor.new
       @doc_errors = Array.new
       @filter_errors = Array.new
@@ -46,6 +47,10 @@ module Rucy
     end
 
     def server_setup(server)
+      server_params = self.server_params
+      server_params.server_setup(self, server)
+      @properties.privilege = server.privilege
+
       logging_params = self.logging_params
       logging_params.server_setup(self, server)
 
@@ -56,24 +61,21 @@ module Rucy
       for mod_path, error in @loader.load_errors
 	server.err("error: not loaded #{mod_path.inspect}: #{error}")
       end
-      doc_factory = @loader.factory
-      doc_factory.add_option(:pw_enc, @pw_enc)
-      doc_factory.setup
-
-      server_params = self.server_params
-      server_params.server_setup(self, server)
+      @factory = @loader.factory
+      @factory.add_option(:pw_enc, @pw_enc)
+      @factory.setup
 
       alias_list = self.aliases
       alias_list.server_setup(self, server)
 
       document_list = self.documents
-      document_list.server_setup(self, server, doc_factory)
+      document_list.server_setup(self, server, @factory)
 
       filter_list = self.filters
-      filter_list.server_setup(self, server, doc_factory)
+      filter_list.server_setup(self, server, @factory)
 
       admin_params = self.admin_params
-      admin_params.server_setup(self, server, @loader, doc_factory, @pw_enc, @page_path)
+      admin_params.server_setup(self, server, @loader, @factory, @pw_enc, @page_path)
 
       @start_time = server.start_time
       @restart_count = server.restart_count
@@ -175,7 +177,7 @@ module Rucy
     end
 
     def documents
-      DocumentList.load(@properties)
+      DocumentList.load(@properties, @factory)
     end
 
     def set_documents(list)
@@ -189,7 +191,7 @@ module Rucy
     end
 
     def filters
-      FilterList.load(@properties)
+      FilterList.load(@properties, @factory)
     end
 
     def set_filters(list)
