@@ -1,8 +1,9 @@
-# $Id: params.rb,v 1.59 2004/10/20 14:51:53 toki Exp $
+# $Id: params.rb,v 1.82 2004/12/12 12:32:16 toki Exp $
 
 require 'wpm'
 require 'wpm/rucydriver'
 require 'wpm/rexml'
+require 'rucy/priv'
 require 'rucy/restart'
 require 'rucy/document'
 require 'rucy/messenger'
@@ -13,8 +14,8 @@ require 'socket'
 
 module Rucy
   module LoadProperties
-    def load(properties)
-      params = self.new
+    def load(properties, *init_args)
+      params = self.new(*init_args)
       params.load(properties)
       params
     end
@@ -48,8 +49,9 @@ module Rucy
     end
 
     def server_setup(control, server, loader, doc_factory, pw_enc, page_path)
-      page_maker = WebPageMakerDocument.new(WPM::XMLAssistByREXML, page_path, 'ControlPanel')
-      page_maker.debug = true
+      page_maker = WebPageMakerDocument.new(WPM::XMLAssistByREXML)
+      page_maker.base_dir = page_path
+      page_maker.main_page = 'ControlPanel'
       page_maker.set_page_option(:control, control)
       page_maker.set_page_option(:factory, doc_factory)
       page_maker.set_page_option(:pw_enc, pw_enc)
@@ -63,7 +65,8 @@ module Rucy
       server.mount(page_maker, '/control')
       if (@params['localhost_only']) then
 	access = loader.RemoteAddressAllowAccessFilter.new
-	access.add_allow_address('127.0.0.1')
+	access.add_allow_address('127.0.0.1') # IPv4 localhost
+	access.add_allow_address('::1')	      # IPv6 localhost
 	server.attach(access, '/control')
       end
       if (@params['admin_user'] && ! @params['admin_user'].empty? &&
@@ -148,7 +151,7 @@ module Rucy
 
       @params['server_type'] = 'multithread' unless (@params.include? 'server_type')
       @params['port'] = 8888 unless (@params.include? 'port')
-      @params['bind_address'] = nil unless (@params.include? 'bind_address')
+      @params['bind_address'] = '0.0.0.0' unless (@params.include? 'bind_address')
       @params['timeout'] = 300 unless (@params.include? 'timeout')
       @params['keep_alive'] = 8 unless (@params.include? 'keep_alive')
       @params['max_requests'] = 32 unless (@params.include? 'max_requests')
@@ -193,8 +196,7 @@ module Rucy
       server.messengers = @params['messengers']
       server.messenger_threads = @params['messenger_threads']
       server.messenger_queue_length = @params['messenger_queue_length']
-      server.subprocess_user = @params['subprocess_user']
-      server.subprocess_group = @params['subprocess_group']
+      server.privilege = Privilege.new(@params['subprocess_user'], @params['subprocess_group'])
       BasicSocket.do_not_reverse_lookup = @params['do_not_reverse_lookup']
       nil
     end
@@ -451,6 +453,12 @@ module Rucy
       end
       for logfile in @params['logfiles']
 	begin
+	  privilege = server.privilege
+	  if (privilege.privileged_user?) then
+	    unless (File.exist? logfile['path']) then
+	      privilege.touch(logfile['path'])
+	    end
+	  end
 	  output = File.open(logfile['path'], 'a')
 	  control.add_logfile(output)
 	  file_logger = Logger.new(output)
@@ -599,6 +607,12 @@ module Rucy
       end
       for logfile in @params['access_logs']
 	begin
+	  privilege = server.privilege
+	  if (privilege.privileged_user?) then
+	    unless (File.exist? logfile['path']) then
+	      privilege.touch(logfile['path'])
+	    end
+	  end
 	  output = File.open(logfile['path'], 'a')
 	  control.add_logfile(output)
 	  access_log = AccessLog.new(output, logfile['format'])
@@ -864,13 +878,197 @@ module Rucy
     end
   end
 
+  class ListEntry
+    def initialize(attrs)
+      @attrs = attrs
+    end
+
+    def name
+      @attrs[name_tag]
+    end
+
+    def name=(new_name)
+      unless (name_list.include? new_name) then
+	raise "unknown name: #{new_name.inspect}"
+      end
+      @attrs[name_tag] = new_name
+    end
+
+    def path
+      @attrs[path_tag]
+    end
+
+    def path=(new_path)
+      case (new_path)
+      when String
+	if (new_path !~ %r"^/") then
+	  raise "not allowed path: #{new_path.inspect}"
+	end
+      when NilClass
+	# checked at saving
+      else
+	raise "not String: #{new_path.inspect}"
+      end
+      @attrs[path_tag] = new_path
+    end
+
+    def mask
+      @attrs[mask_tag]
+    end
+
+    def mask=(new_mask)
+      @attrs[mask_tag] = new_mask
+    end
+
+    def virtual_host
+      @attrs['virtual_host']
+    end
+
+    def virtual_host=(new_host)
+      case (new_host)
+      when String, NilClass
+	# nothing to do.
+      else
+	raise "not allowed host: #{new_host.inspect}"
+      end
+      @attrs['virtual_host'] = new_host
+    end
+
+    def comment
+      @attrs['comment']
+    end
+
+    def comment=(new_comment)
+      case (new_comment)
+      when String, NilClass
+	# nothing to do.
+      else
+	raise "not allowed comment: #{new_comment.inspect}"
+      end
+      @attrs['comment'] = new_comment
+    end
+
+    def init(name)
+      self.name = name
+      @attrs['arguments'].clear
+      for arg_info in arg_info_alist(name)
+	arg_name = arg_info[0]
+	arg_type = arg_info[1]
+	arg_default = arg_info[2]
+	case (arg_type)
+	when :select
+	  arg_value = arg_default[0]
+	when :checkset
+	  arg_value = Hash.new
+	  for name, value in arg_default
+	    arg_value[name] = value
+	  end
+	when :radio
+	  arg_value = arg_default[0]
+	else
+	  arg_value = arg_default
+	end
+	@attrs['arguments'].push(arg_value)
+      end
+
+      nil
+    end
+
+    def args
+      @attrs['arguments'].dup
+    end
+
+    def args2
+      arg_value_list = @attrs['arguments']
+      arg_info_alist = self.arg_info_alist(self.name)
+      if (arg_value_list.length != arg_info_alist.length) then
+	raise 'mismatch arguments'
+      end
+
+      arg_list = Array.new
+      arg_value_list.each_with_index do |value, i|
+	arg_list.push({ :name => arg_info_alist[i][0],
+			:type => arg_info_alist[i][1],
+			:default => arg_info_alist[i][2],
+			:value => value
+		      })
+      end
+
+      arg_list
+    end
+
+    def set_arg_at(pos, value)
+      arg_info = arg_info_alist(self.name)[pos]
+      case (arg_info[1])
+      when :string, :password, :text
+	case (value)
+	when String, NilClass
+	  # nothing to do.
+	else
+	  raise "not allowed as string: #{value.inspect}"
+	end
+      when :number
+	case (value)
+	when Integer, NilClass
+	  # nothing to do.
+	else
+	  raise "not allowed as integer: #{value.inspect}"
+	end
+      when :regexp
+	case (value)
+	when Regexp, NilClass
+	  # nothing to do.
+	else
+	  raise "not allowed as regexp: #{value.inspect}"
+	end
+      when :bool
+	case (value)
+	when TrueClass, FalseClass
+	  # nothing to do.
+	else
+	  raise "not allowed as bool: #{value.inspect}"
+	end
+      when :select, :radio
+	unless (arg_info[2].include? value) then
+	  raise "not included in allowed list: #{value.inspect}"
+	end
+      when :checkset
+	case (value)
+	when Hash
+	  key_check = Hash[*value.keys.map{|k| [ k, true ] }.flatten]
+	  for key, flag in arg_info[2]
+	    unless (value.include? key) then
+	      raise "not allowed as checkset by lack of key: #{value.inspect}"
+	    end
+	    case (value[key])
+	    when TrueClass, FalseClass
+	      # nothing to do.
+	    else
+	      raise "not allowed as checkset by not boolean flag: #{value.inspect}"
+	    end
+	    key_check.delete(key)
+	  end
+	  unless (key_check.empty?) then
+	    raise "not allowed as checkset by excessive key: #{value.inspect}"
+	  end
+	else
+	  raise "not allowed as checkset: #{value.inspect}"
+	end
+      else
+	raise "unknown argument type: #{arg_info[1]}"
+      end
+      @attrs['arguments'][pos] = value
+    end
+  end
+
   class DocumentList
     extend Forwardable
     extend LoadProperties
     include Enumerable
 
-    def initialize
+    def initialize(factory)
       @list = nil
+      @factory = factory
     end
 
     def load(properties)
@@ -879,6 +1077,12 @@ module Rucy
     end
 
     def save(properties)
+      for entry in @list
+	case (entry['mount_path'])
+	when NilClass
+	  raise 'required mount path'
+	end
+      end
       properties.set_list('documents', @list)
       nil
     end
@@ -918,114 +1122,35 @@ module Rucy
     def_delegator :@list, :size
     def_delegator :@list, :length
 
-    class MountParams
-      def initialize(attrs)
-	@attrs = attrs
+    class MountParams < ListEntry
+      def initialize(attrs, factory)
+	super(attrs)
+	@factory = factory
       end
 
-      def name
-	@attrs['document']
+      def name_tag
+	'document'
       end
 
-      def name=(new_name)
-	@attrs['document'] = new_name
+      def path_tag
+	'mount_path'
       end
 
-      def args
-	@attrs['arguments'].dup
+      def mask_tag
+	'mount_mask'
       end
 
-      def set_args_at(pos, value)
-	@attrs['arguments'][pos] = value
+      def name_list
+	@factory.doc_names
       end
 
-      def path
-	@attrs['mount_path']
-      end
-
-      def path=(new_path)
-	@attrs['mount_path'] = new_path
-      end
-
-      def mask
-	@attrs['mount_mask']
-      end
-
-      def mask=(new_mask)
-	@attrs['mount_mask'] = new_mask
-      end
-
-      def virtual_host
-	@attrs['virtual_host']
-      end
-
-      def virtual_host=(new_host)
-	@attrs['virtual_host'] = new_host
-      end
-
-      def comment
-	@attrs['comment']
-      end
-
-      def comment=(new_comment)
-	@attrs['comment'] = new_comment
-      end
-
-      # for backward compatibility
-
-      def [](name)
-	case (name)
-	when 'document'
-	  self.name
-	when 'arguments'
-	  self.args
-	when 'mount_path'
-	  self.path
-	when 'mount_mask'
-	  self.mask
-	when 'virtual_host'
-	  self.virtual_host
-	when 'comment'
-	  self.comment
-	else
-	  raise "unknown key word: #{name.inspect}"
-	end
-      end
-
-      def []=(name, value)
-	case (name)
-	when 'document'
-	  self.name = value
-	when 'arguments'
-	  value.each_with_index do |v, i|
-	    set_args_at(i, v)
-	  end
-	when 'mount_path'
-	  self.path = value
-	when 'mount_mask'
-	  self.mask = value
-	when 'virtual_host'
-	  self.virtual_host = value
-	when 'comment'
-	  self.comment = value
-	else
-	  raise "unknown key word: #{name.inspect}"
-	end
-      end
-
-      def to_hash
-	{ 'document' => self.name,
-	  'arguments' => self.args,
-	  'mount_path' => self.path,
-	  'mount_mask' => self.mask,
-	  'virtual_host' => self.virtual_host,
-	  'comment' => self.comment
-	}
+      def arg_info_alist(name)
+	@factory.doc_args(name)
       end
     end
 
     def [](pos)
-      MountParams.new(@list[pos])
+      MountParams.new(@list[pos], @factory)
     end
 
     def add_entry
@@ -1051,35 +1176,7 @@ module Rucy
 
     def each
       for attrs in @list
-	yield(MountParams.new(attrs))
-      end
-      nil
-    end
-
-    # for backward compatibility
-
-    def push(attrs)
-      self.add_entry
-      params = self[-1]
-      params.name = attrs['document'] if (attrs.include? 'document')
-      if (attrs.include? 'arguments') then
-	attrs['arguments'].each_with_index do |v, i|
-	  params.set_args_at(i, v)
-	end
-      end
-      params.path = attrs['mount_path'] if (attrs.include? 'mount_path')
-      params.mask = attrs['mount_mask'] if (attrs.include? 'mount_mask')
-      params.virtual_host = attrs['virtual_host'] if (attrs.include? 'virtual_host')
-      params.comment = attrs['comment'] if (attrs.include? 'comment')
-      nil
-    end
-
-    def []=(pos, attrs)
-      if (pos == @list.length && (attrs.kind_of? Hash)) then
-	push(attrs)
-	return self[-1]
-      else
-	raise 'failed to add entry of document list.'
+	yield(MountParams.new(attrs, @factory))
       end
       nil
     end
@@ -1090,8 +1187,9 @@ module Rucy
     extend LoadProperties
     include Enumerable
 
-    def initialize
+    def initialize(factory)
       @list = nil
+      @factory = factory
     end
 
     def load(properties)
@@ -1100,6 +1198,12 @@ module Rucy
     end
 
     def save(properties)
+      for entry in @list
+	case (entry['attach_path'])
+	when NilClass
+	  raise 'required attach path'
+	end
+      end
       properties.set_list('filters', @list)
       nil
     end
@@ -1121,13 +1225,13 @@ module Rucy
 	  end
 	rescue StandardError, ScriptError
 	  server.err("error: not attached #{name.inspect} filter: (#{$!.class}) #{$!}")
-	  @filter_errors.push({ :filter => name,
-				:arguments => args,
-				:attach_path => path,
-				:attach_mask => mask,
-				:virtual_host => host,
-				:exception => $!
-			      })
+	  control.filter_errors.push({ :filter => name,
+				       :arguments => args,
+				       :attach_path => path,
+				       :attach_mask => mask,
+				       :virtual_host => host,
+				       :exception => $!
+				     })
 	end
       end
       nil
@@ -1139,115 +1243,35 @@ module Rucy
     def_delegator :@list, :size
     def_delegator :@list, :length
 
-    class AttachParams
-      def initialize(attrs)
-	@attrs = attrs
+    class AttachParams < ListEntry
+      def initialize(attrs, factory)
+	super(attrs)
+	@factory = factory
       end
 
-      def name
-	@attrs['filter']
+      def name_tag
+	'filter'
       end
 
-      def name=(new_name)
-	@attrs['filter'] = new_name
+      def path_tag
+	'attach_path'
       end
 
-      def args
-	@attrs['arguments'].dup
+      def mask_tag
+	'attach_mask'
       end
 
-      def set_args_at(pos, value)
-	@attrs['arguments'][pos] = value
-	nil
+      def name_list
+	@factory.filter_names
       end
 
-      def path
-	@attrs['attach_path']
-      end
-
-      def path=(new_path)
-	@attrs['attach_path'] = new_path
-      end
-
-      def mask
-	@attrs['attach_mask']
-      end
-
-      def mask=(new_mask)
-	@attrs['attach_mask'] = new_mask
-      end
-
-      def virtual_host
-	@attrs['virtual_host']
-      end
-
-      def virtual_host=(new_host)
-	@attrs['virtual_host'] = new_host
-      end
-
-      def comment
-	@attrs['comment']
-      end
-
-      def comment=(new_comment)
-	@attrs['comment'] = new_comment
-      end
-
-      # for backward compatibility
-
-      def [](name)
-	case (name)
-	when 'filter'
-	  self.name
-	when 'arguments'
-	  self.args
-	when 'attach_path'
-	  self.path
-	when 'attach_mask'
-	  self.mask
-	when 'virtual_host'
-	  self.virtual_host
-	when 'comment'
-	  self.comment
-	else
-	  raise "unknown key word: #{name.inspect}"
-	end
-      end
-
-      def []=(name, value)
-	case (name)
-	when 'filter'
-	  self.name = value
-	when 'arguments'
-	  value.each_with_index do |v, i|
-	    set_args_at(i, v)
-	  end
-	when 'attach_path'
-	  self.path = value
-	when 'attach_mask'
-	  self.mask = value
-	when 'virtual_host'
-	  self.virtual_host = value
-	when 'comment'
-	  self.comment = value
-	else
-	  raise "unknown key word: #{name.inspect}"
-	end
-      end
-
-      def to_hash
-	{ 'filter' => self.name,
-	  'arguments' => self.args,
-	  'attach_path' => self.path,
-	  'attach_mask' => self.mask,
-	  'virtual_host' => self.virtual_host,
-	  'comment' => self.comment
-	}
+      def arg_info_alist(name)
+	@factory.filter_args(name)
       end
     end
 
     def [](pos)
-      AttachParams.new(@list[pos])
+      AttachParams.new(@list[pos], @factory)
     end
 
     def add_entry
@@ -1273,33 +1297,7 @@ module Rucy
 
     def each
       for attrs in @list
-	yield(AttachParams.new(attrs))
-      end
-      nil
-    end
-
-    def push(attrs)
-      self.add_entry
-      params = self[-1]
-      params.name = attrs['filter'] if (attrs.include? 'filter')
-      if (attrs.include? 'arguments') then
-	attrs['arguments'].each_with_index do |v, i|
-	  params.set_args_at(i, v)
-	end
-      end
-      params.path = attrs['attach_path'] if (attrs.include? 'attach_path')
-      params.mask = attrs['attach_mask'] if (attrs.include? 'attach_mask')
-      params.virtual_host = attrs['virtual_host'] if (attrs.include? 'virtual_host')
-      params.comment = attrs['comment'] if (attrs.include? 'comment')
-      nil
-    end
-
-    def []=(pos, attrs)
-      if (pos == @list.length && (attrs.kind_of? Hash)) then
-	push(attrs)
-	return self[-1]
-      else
-	raise 'failed to add entry of document list.'
+	yield(AttachParams.new(attrs, @factory))
       end
       nil
     end
