@@ -1,4 +1,4 @@
-# $Id: properties.rb,v 1.2 2004/08/11 14:00:52 toki Exp $
+# $Id: properties.rb,v 1.3 2004/12/11 16:25:54 toki Exp $
 
 require 'thread'
 require 'yaml/store'
@@ -10,12 +10,20 @@ module Rucy
 
   class Properties
     def initialize(path)
+      @path = path
       @store = YAML::Store.new(path)
       @lock = Mutex.new
+      @privilege = nil
     end
 
+    attr_writer :privilege
+
     def transaction
       @lock.synchronize{
+	if (@privilege && @privilege.privileged_user?) then
+	  @privilege.touch(@path)
+	  @privilege.touch(@path + '~')
+	end
 	@store.transaction{
 	  yield
 	}
