@@ -1,8 +1,7 @@
 #!/usr/local/bin/ruby
-# $Id: rucy.rb,v 1.6 2004/10/02 01:00:13 toki Exp $
+# $Id: rucy.rb,v 1.8 2004/12/09 04:34:23 toki Exp $
 
 require 'getoptlong'
-
 getoptlong = GetoptLong.new([ '--help', '-h', GetoptLong::NO_ARGUMENT ],
 			    [ '--version', '-v', GetoptLong::NO_ARGUMENT ],
 			    [ '--daemon', '-d', GetoptLong::NO_ARGUMENT ],
@@ -48,18 +47,18 @@ $:.push(lib_ctrl)
 $:.push(lib_wpm)
 
 require 'rucy/version'
-
 print Rucy::RUCY_TOKEN, "\n" if show_version
 print usage if show_help
 exit 1 if (show_help || show_version)
 
+require 'rucy/rc_d'
 require 'rucy/logger'
 require 'rucy/server'
 require 'rucy/document'
 require 'rucy/control'
 require 'rucy/properties'
-
 server = Rucy::Server.new
+
 server.open_hook{|s|
   loader = Rucy::DocumentLoader.new(mod_docs)
   properties = Rucy::Properties.new(store_db)
@@ -74,4 +73,6 @@ if ($RUCY_DAEMON) then
   Rucy::Server.daemon
   trap('HUP') { server.restart }
 end
+rc_d = Rucy::RC_d.new(Rucy::RC_d::LOCK_FILE)
+rc_d.lock
 server.accept
