@@ -1,13 +1,12 @@
-# $Id: pseudo_req_res.rb,v 1.3 2004/09/23 13:18:25 toki Exp $
+# $Id: pseudo_req_res.rb,v 1.4 2004/12/12 00:20:24 toki Exp $
 
+require 'forwarder'
 require 'rucy/logger'
 require 'rucy/request'
 require 'rucy/response'
 
 module TestRucy
   module PseudoLogger
-    include Rucy::LoggingLevel
-
     def setup
       super
       @log_emerg = ''
@@ -18,26 +17,30 @@ module TestRucy
       @log_notice = ''
       @log_info = ''
       @log_debug = ''
-      @logger = self
+      @logger = Forwarder.new(self)
+      class << @logger
+	include Rucy::LoggingLevel
+	def_delegator :__getobj__, :messg
+      end
     end
 
     def messg(level, messg, format=true)
       case (level)
-      when LOG_EMERG
+      when Rucy::LoggingLevel::LOG_EMERG
 	@log_emerg << messg << "\n"
-      when LOG_ALERT
+      when Rucy::LoggingLevel::LOG_ALERT
 	@log_alert << messg << "\n"
-      when LOG_CRIT
+      when Rucy::LoggingLevel::LOG_CRIT
 	@log_crit << messg << "\n"
-      when LOG_ERR
+      when Rucy::LoggingLevel::LOG_ERR
 	@log_err << messg << "\n"
-      when LOG_WARNING
+      when Rucy::LoggingLevel::LOG_WARNING
 	@log_warning << messg << "\n"
-      when LOG_NOTICE
+      when Rucy::LoggingLevel::LOG_NOTICE
 	@log_notice << messg << "\n"
-      when LOG_INFO
+      when Rucy::LoggingLevel::LOG_INFO
 	@log_info << messg << "\n"
-      when LOG_DEBUG
+      when Rucy::LoggingLevel::LOG_DEBUG
 	@log_debug << messg << "\n"
       else
 	assert_fail("unknown logging level: #{level.inspect}")
@@ -55,7 +58,12 @@ module TestRucy
       @response = Rucy::Response.new
       @messg_head = nil
       @messg_body = ''
-      @response.set_writer(self)
+      @writer = Forwarder.new(self)
+      class << @writer
+	def_delegator :__getobj__, :write_head
+	def_delegator :__getobj__, :write
+      end
+      @response.set_writer(@writer)
     end
 
     def write_head(response)
@@ -95,12 +103,17 @@ module TestRucy
       @publish_local_path = nil
       @publish_content_type = 'text/plain'
       @publish_messg_body = 'foo'
+      @document = Forwarder.new(self)
+      class << @document
+	def_delegator :__getobj__, :each
+	def_delegator :__getobj__, :publish
+      end
     end
 
     def each(traversed={})
-      unless (traversed.include? self) then
+      unless (traversed.include? @document) then
 	@each_call += 1
-	yield(self)
+	yield(@document)
       end
       nil
     end
@@ -131,6 +144,15 @@ module TestRucy
       @filter_close_call = 0
       @filter_script_name = nil
       @filter_request_path = nil
+      @filter = Forwarder.new(self)
+      class << @filter
+	def_delegator :__getobj__, :init
+	def_delegator :__getobj__, :final
+	def_delegator :__getobj__, :filter_open
+	def_delegator :__getobj__, :filter_head
+	def_delegator :__getobj__, :filter_body
+	def_delegator :__getobj__, :filter_close
+      end
     end
 
     def init
