@@ -1,20 +1,43 @@
 #!/usr/local/bin/ruby
-# $Id: test_AdminPassword.rb,v 1.3 2004/10/13 15:21:13 toki Exp $
+# $Id: test_AdminPassword.rb,v 1.4 2004/11/30 17:15:57 toki Exp $
 
 require 'rubyunit'
+require 'forwarder'
 require 'wpm'
 require 'rucy/passwd'
 
 module TestRucy
   class TestAdminPassword < RUNIT::TestCase
     def setup
-      # for WPM::Driver class
+      # for WPM::Page class
       @driver_call = 0
+
+      @page = Forwarder.new(self)
+      class << @page
+	def_delegator :__getobj__, :driver
+      end
+
+      # for WPM::MessageManipulator class
       @redirect_call = 0
       @redirect_last_page_name = nil
       @redirect_last_query_params = nil
 
+      @driver = Forwarder.new(self)
+      class << @driver
+	def_delegator :__getobj__, :redirect
+      end
+
       # for Rucy::Control class
+      @admin_params_call = 0
+      @set_admin_params_call = 0
+
+      @control = Forwarder.new(self)
+      class << @control
+	def_delegator :__getobj__, :admin_params
+	def_delegator :__getobj__, :set_admin_params
+      end
+
+      # for Rucy::AdminParams class
       @modified_count_call = 0
       @set_modified_count_call = 0
       @set_modified_count_value = nil
@@ -22,30 +45,51 @@ module TestRucy
 	'admin_user' => 'admin',
 	'admin_password' => '',
       }
-      @admin_params_call = 0
-      @set_admin_params_call = 0
       @admin_user_call = 0
       @set_admin_user_call = 0
       @admin_password_call = 0
       @set_admin_password_call = 0
 
+      @admin_params = Forwarder.new(self)
+      class << @admin_params
+	def_delegator :__getobj__, :modified_count
+	def_delegator :__getobj__, :modified_count=
+	def_delegator :__getobj__, :admin_user
+	def_delegator :__getobj__, :admin_user=
+	def_delegator :__getobj__, :admin_password
+	def_delegator :__getobj__, :admin_password=
+      end
+
       # for Rucy::PasswordEncryptor
       @pw_enc = Rucy::PasswordEncryptor.new
       @crypt_call = 0
       @crypt_password_list = []
 
+      @pw_enc_stab = Forwarder.new(self)
+      class << @pw_enc_stab
+	def_delegator :__getobj__, :crypt
+      end
+
       # setup WPM::PageContext class
       loader = WPM::Loader.new('../control/AdminPassword/AdminPassword.rb')
-      @AdminPassword = loader.const_get('AdminPassword').new(self, { :control => self, :pw_enc => self })
+      options = {
+	:control => @control,
+	:pw_enc => @pw_enc_stab
+      }
+      @AdminPassword = loader.const_get('AdminPassword').new(@page, options)
       assert((@AdminPassword.is_a? WPM::PageContext))
       @AdminPassword.init_context
     end
 
+    # for WPM::Page class
+
     def driver
       @driver_call += 1
-      self
+      @driver
     end
 
+    # for WPM::MessageManipulator class
+
     def redirect(page_name, query_params=nil)
       @redirect_call += 1
       @redirect_last_page_name = page_name
@@ -53,14 +97,16 @@ module TestRucy
       nil
     end
 
+    # for Rucy::Control class
+
     def admin_params
       @admin_params_call += 1
-      self
+      @admin_params
     end
 
     def set_admin_params(params)
       @set_admin_params_call += 1
-      assert_equal(self, params)
+      assert_equal(@admin_params, params)
       nil
     end
 
@@ -74,6 +120,8 @@ module TestRucy
       @set_modified_count_value = modified_count
     end
 
+    # for Rucy::AdminParams class
+
     def admin_user
       @admin_user_call += 1
       @store['admin_user']
@@ -94,12 +142,16 @@ module TestRucy
       @store['admin_password'] = new_password
     end
 
+    # for Rucy::PasswordEncryptor class
+
     def crypt(password, salt=nil)
       @crypt_call += 1
       @crypt_password_list.push(password)
       @pw_enc.crypt(password, salt || @pw_enc.salt)
     end
 
+    # test
+
     def test_modified_count
       assert_equal(1, @admin_params_call)
       assert_equal(0, @AdminPassword.modified_count)
@@ -110,6 +162,8 @@ module TestRucy
     end
 
     def test_change_username
+      assert_equal('admin', @AdminPassword.username)
+      assert_equal(1, @admin_user_call)
       @AdminPassword.username = 'alice'
       @AdminPassword.change_password
       assert_equal(1, @set_admin_params_call)
