@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test_StyleSheet.rb,v 1.1.1.1 2004/04/04 15:22:50 toki Exp $
+# $Id: test_StyleSheet.rb,v 1.2 2004/10/13 15:21:49 toki Exp $
 
 require 'rubyunit'
 require 'wpm'
@@ -8,7 +8,7 @@ module TestRucy
   class TestStyleSheet < RUNIT::TestCase
     def setup
       loader = WPM::Loader.new('../control/StyleSheet/StyleSheet.rb')
-      @StyleSheet = loader.const_get('StyleSheet').new(self, :control => self)
+      @StyleSheet = loader.const_get('StyleSheet').new(self, { :control => self })
       assert((@StyleSheet.is_a? WPM::PageContext))
       @StyleSheet.init_context
     end
