@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test_auth.rb,v 1.4 2004/10/02 00:41:56 toki Exp $
+# $Id: test_auth.rb,v 1.5 2004/10/30 09:00:57 toki Exp $
 
 require 'rubyunit'
 require 'pseudo_req_res'
@@ -111,24 +111,24 @@ module TestRucy
     end
   end
 
-  class TestBasicAuthFilterFactory < RUNIT::TestCase
+  class TestBasicAuthFilterBuilder < RUNIT::TestCase
     def setup
       @loader = Rucy::SimpleLoader.new
       @loader.load('../mod_docs/auth.rb')
-      @BasicAuthFilterFactory = @loader.const_get('BasicAuthFilterFactory')
-      @factory = @BasicAuthFilterFactory.instance
+      @BasicAuthFilterBuilder = @loader.const_get('BasicAuthFilterBuilder')
+      @builder = @BasicAuthFilterBuilder.instance
     end
 
     def test_set_filter_option
-      @factory.set_filter_option({ :pw_enc => Rucy::PasswordEncryptor.new })
+      @builder.set_filter_option({ :pw_enc => Rucy::PasswordEncryptor.new })
     end
 
     def test_filter_name
-      assert_equal('BasicAuth', @factory.filter_name)
+      assert_equal('BasicAuth', @builder.filter_name)
     end
 
     def test_filter_args
-      args = @factory.filter_args
+      args = @builder.filter_args
       assert_equal([ 'realm', :string, nil ], args[0])
       assert_equal([ 'user 1', :string, nil ], args[1])
       assert_equal([ 'password 1', :password, nil  ], args[2])
@@ -143,7 +143,7 @@ module TestRucy
     end
 
     def test_new
-      filter = @factory.new('test',
+      filter = @builder.new('test',
 			    'foo', 'himitsu',
 			    nil, nil,
 			    nil, nil,
