@@ -1,4 +1,4 @@
-# $Id: test_cgi.rb,v 1.4 2004/09/29 14:43:08 toki Exp $
+# $Id: test_cgi.rb,v 1.6 2004/12/12 00:20:31 toki Exp $
 
 require 'rubyunit'
 require 'pseudo_req_res'
@@ -64,7 +64,7 @@ module TestRucy
       @request.method = 'GET'
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -86,7 +86,7 @@ module TestRucy
       @request.method = 'GET'
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(201, @messg_head.status)
       assert_equal('Created', @messg_head.reason)
@@ -108,7 +108,7 @@ module TestRucy
       @request.method = 'GET'
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -133,7 +133,7 @@ module TestRucy
       @request.uri = 
       @request.uri = '/test.cgi?foo+bar'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -158,7 +158,7 @@ module TestRucy
       @request.uri = 
       @request.uri = '/test.cgi?foo+bar'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -180,7 +180,7 @@ module TestRucy
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
       @request.set_header('Authorization', 'Basic YWxpY2U6Zm9v')
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -203,7 +203,7 @@ module TestRucy
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
       @request.set_header('Authorization', 'Basic YWxpY2U6Zm9v')
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -225,7 +225,7 @@ module TestRucy
       @request.uri = 
       @request.uri = '/test.cgi/foo/bar'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -248,7 +248,7 @@ module TestRucy
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
       @request.set_header('User-Agent', 'TestRucy')
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -282,7 +282,7 @@ module TestRucy
       post_reader = PseudoIO.new
       post_reader.write(messg)
       @request.set_reader(post_reader)
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -318,7 +318,7 @@ module TestRucy
       @request.method = 'GET'
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -341,7 +341,7 @@ module TestRucy
       @request.method = 'GET'
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -367,7 +367,7 @@ module TestRucy
       @request.uri = 
       @request.uri = '/test.cgi?foo+bar'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -393,7 +393,7 @@ module TestRucy
       @request.uri = 
       @request.uri = '/test.cgi?foo+bar'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -416,7 +416,7 @@ module TestRucy
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
       @request.set_header('Authorization', 'Basic YWxpY2U6Zm9v')
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -440,7 +440,7 @@ module TestRucy
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
       @request.set_header('Authorization', 'Basic YWxpY2U6Zm9v')
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -463,7 +463,7 @@ module TestRucy
       @request.uri = 
       @request.uri = '/test.cgi/foo/bar'
       @request.version = 'HTTP/1.1'
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -487,7 +487,7 @@ module TestRucy
       @request.uri = '/test.cgi'
       @request.version = 'HTTP/1.1'
       @request.set_header('User-Agent', 'TestRucy')
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -522,7 +522,7 @@ module TestRucy
       post_reader = PseudoIO.new
       post_reader.write(messg)
       @request.set_reader(post_reader)
-      @cgi.publish('', @request, @response, self)
+      @cgi.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -533,24 +533,24 @@ module TestRucy
     end
   end
 
-  class TestCGIDocumentFactory < RUNIT::TestCase
+  class TestCGIDocumentBuilder < RUNIT::TestCase
     def setup
       @loader = Rucy::SimpleLoader.new
       @loader.load('../mod_docs/cgi.rb')
-      @CGIDocumentFactory = @loader.const_get('CGIDocumentFactory')
-      @factory = @CGIDocumentFactory.instance
+      @CGIDocumentBuilder = @loader.const_get('CGIDocumentBuilder')
+      @builder = @CGIDocumentBuilder.instance
     end
 
     def test_set_doc_option
-      @factory.set_doc_option(Hash.new)
+      @builder.set_doc_option(Hash.new)
     end
 
     def test_doc_name
-      assert_equal('CGI', @factory.doc_name)
+      assert_equal('CGI', @builder.doc_name)
     end
 
     def test_doc_args
-      args = @factory.doc_args
+      args = @builder.doc_args
       assert_equal([ 'CGI directory', :string, nil ], args[0])
       assert_equal([ 'CGI run command (optional)', :string, nil ], args[1])
       assert_equal([ 'none parsed header', :bool, false ], args[2])
@@ -569,7 +569,7 @@ module TestRucy
     end
 
     def test_new
-      doc = @factory.new('/', nil, false, false, false,
+      doc = @builder.new('/', nil, false, false, false,
 			 nil, nil,
 			 nil, nil,
 			 nil, nil,
