@@ -1,10 +1,11 @@
 #!/usr/local/bin/ruby
-# $Id: test_control.rb,v 1.41 2004/10/20 14:37:36 toki Exp $
+# $Id: test_control.rb,v 1.46 2004/12/12 12:32:20 toki Exp $
 
 require 'rubyunit'
+require 'forwarder'
+require 'pseudo_props'
 require 'wpm'
 require 'wpm/rucydriver'
-require 'rucy/properties'
 require 'rucy/control'
 require 'rucy/logger'
 require 'rucy/document'
@@ -12,23 +13,18 @@ require 'rucy/passwd'
 
 module TestRucy
   class TestControl < RUNIT::TestCase
-    include Rucy::LoggingLevel
+    include PseudoProperties
 
     def setup
+      super
+
       # for Rucy::Properties class
-      @properties = Hash.new
-      @list_call = 0
-      @list_last_name = nil
-      @set_list_call = 0
-      @set_list_last_name = nil
-      @map_call = 0
-      @map_last_name = nil
-      @set_map_call = 0
-      @set_map_last_name = nil
-      @params_call = 0
-      @params_last_names = nil
-      @set_params_call = 0
-      @set_params_last_names = nil
+      @set_properties_privilege_call = 0
+      @set_properties_privilege_priv = nil
+
+      class << @properties
+	def_delegator :__getobj__, :_privilge=, :privilege=
+      end
 
       # for Rucy::Server class
       @start_time_call = 0
@@ -38,30 +34,30 @@ module TestRucy
       @close_call = 0
       @restart_signal_call = 0
       @restart_signal = nil
-      @port_call = 0
+      @set_port_call = 0
       @port = nil
-      @bind_address_call = 0
+      @port_call = 0
+      @set_bind_address_call = 0
       @bind_address = nil
-      @timeout_call = 0
+      @set_timeout_call = 0
       @timeout = nil
-      @keep_alive_call = 0
+      @set_keep_alive_call = 0
       @keep_alive = nil
-      @max_requests_call = 0
+      @set_max_requests_call = 0
       @max_requests = nil
-      @queue_length_call = 0
+      @set_queue_length_call = 0
       @queue_length = nil
-      @messengers_call = 0
+      @set_messengers_call = 0
       @messengers = nil
-      @messenger_factory_call = 0
+      @set_messenger_factory_call = 0
       @messenger_factory = nil
-      @messenger_threads_call = 0
+      @set_messenger_threads_call = 0
       @messenger_threads = nil
-      @messenger_queue_length_call = 0
+      @set_messenger_queue_length_call = 0
       @messenger_queue_length = nil
-      @subprocess_user_call = 0
-      @subprocess_user = nil
-      @subprocess_group_call = 0
-      @subprocess_group = nil
+      @privilege_call = 0
+      @set_privilege_call = 0
+      @privilege = nil
       @add_logger_call = 0
       @add_access_log_call = 0
       @logging_access_call = 0
@@ -77,77 +73,80 @@ module TestRucy
       @folder = Rucy::FolderDocument.new
       @close_hook_call = 0
 
+      @server = Forwarder.new(self)
+      class << @server
+	include Rucy::LoggingLevel
+	def_delegator :__getobj__, :start_time
+	def_delegator :__getobj__, :restart_count
+	def_delegator :__getobj__, :restart_time
+	def_delegator :__getobj__, :restart
+	def_delegator :__getobj__, :close
+	def_delegator :__getobj__, :restart_signal=
+	def_delegator :__getobj__, :port
+	def_delegator :__getobj__, :port=
+	def_delegator :__getobj__, :bind_address=
+	def_delegator :__getobj__, :timeout=
+	def_delegator :__getobj__, :keep_alive=
+	def_delegator :__getobj__, :max_requests=
+	def_delegator :__getobj__, :queue_length=
+	def_delegator :__getobj__, :messengers=
+	def_delegator :__getobj__, :messenger_factory=
+	def_delegator :__getobj__, :messenger_threads=
+	def_delegator :__getobj__, :messenger_queue_length=
+	def_delegator :__getobj__, :privilege
+	def_delegator :__getobj__, :privilege=
+	def_delegator :__getobj__, :add_logger
+	def_delegator :__getobj__, :add_access_log
+	def_delegator :__getobj__, :logging_access
+	def_delegator :__getobj__, :messg
+	def_delegator :__getobj__, :set_alias
+	def_delegator :__getobj__, :set_virtual_alias
+	def_delegator :__getobj__, :mount
+	def_delegator :__getobj__, :virtual_mount
+	def_delegator :__getobj__, :attach
+	def_delegator :__getobj__, :virtual_attach
+	def_delegator :__getobj__, :close_hook
+      end
+
       # for Rucy::PasswordEncryptor
-      @pw_enc = Rucy::PasswordEncryptor.new
+      @pw_enc_orig = Rucy::PasswordEncryptor.new
       @crypt_call = 0
 
+      @pw_enc = Forwarder.new(self)
+      class << @pw_enc
+	def_delegator :__getobj__, :crypt
+      end
+
       # for Rucy::DocumentLoader class
-      @loader = Rucy::DocumentLoader.new('../mod_docs')
+      @loader_orig = Rucy::DocumentLoader.new('../mod_docs')
       @load_call = 0
       @load_errors_call = 0
       @factory_call = 0
       @RemoteAddressAllowAccessFilter_call = 0
       @BasicAuthFilter_call = 0
 
+      @loader = Forwarder.new(self)
+      class << @loader
+	def_delegator :__getobj__, :load
+	def_delegator :__getobj__, :load_errors
+	def_delegator :__getobj__, :factory
+	def_delegator :__getobj__, :RemoteAddressAllowAccessFilter
+	def_delegator :__getobj__, :BasicAuthFilter
+      end
+
+      # test target
       @control = nil
     end
 
-    def list(name)
-      @list_call += 1
-      @list_last_name = name
-      if (@properties[name]) then
-	assert_instance_of(Array, @properties[name])
-	return @properties[name].dup
-      else
-	return Array.new
-      end
-    end
+    # for Rucy::Properties class
 
-    def set_list(name, list)
-      @set_list_call += 1
-      @set_list_last_name = name
-      @properties[name] = list.dup
+    def _privilge=(new_priv)
+      @set_properties_privilege_call += 1
+      @set_properties_privilege_priv = new_priv
       nil
     end
 
-    def map(name)
-      @map_call += 1
-      @map_last_name = name
-      if (@properties[name]) then
-	assert_instance_of(Hash, @properties[name])
-	return @properties[name].dup
-      else
-	return Hash.new
-      end
-    end
-
-    def set_map(name, map)
-      @set_map_call += 1
-      @set_map_last_name = name
-      @properties[name] = map.dup
-      nil
-    end
-
-    def params(*names)
-      @params_call += 1
-      @params_last_names = names
-      params = Hash.new
-      for name in names
-	if (@properties.include? name) then
-	  params[name] = @properties[name]
-	end
-      end
-      params
-    end
-
-    def set_params(params)
-      @set_params_call += 1
-      @set_params_last_names = params.keys
-      for name, value in params
-	@properties[name] = value
-      end
-      nil
-    end
+    # for Rucy::Server class
 
     def start_time
       @start_time_call += 1
@@ -177,72 +176,73 @@ module TestRucy
     def restart_signal=(restart_signal)
       @restart_signal_call += 1
       @restart_signal = restart_signal
-      @restart_signal.server = self
+      @restart_signal.server = @server
       restart_signal
     end
 
     def port
+      @port_call += 1
       @port
     end
 
     def port=(port)
-      @port_call += 1
+      @set_port_call += 1
       @port = port
     end
 
     def bind_address=(new_address)
-      @bind_address_call += 1
+      @set_bind_address_call += 1
       @bind_address = new_address
     end
 
     def timeout=(timeout)
-      @timeout_call += 1
+      @set_timeout_call += 1
       @timeout = timeout
     end
 
     def keep_alive=(keep_alive)
-      @keep_alive_call += 1
+      @set_keep_alive_call += 1
       @keep_alive = keep_alive
     end
 
     def max_requests=(max_requests)
-      @max_requests_call += 1
+      @set_max_requests_call += 1
       @max_requests = max_requests
     end
 
     def queue_length=(queue_length)
-      @queue_length_call += 1
+      @set_queue_length_call += 1
       @queue_length = queue_length
     end
 
     def messengers=(messengers)
-      @messengers_call += 1
+      @set_messengers_call += 1
       @messengers = messengers
     end
 
     def messenger_factory=(messenger_factory)
-      @messenger_factory_call += 1
+      @set_messenger_factory_call += 1
       @messenger_factory = messenger_factory
     end
 
     def messenger_threads=(messenger_threads)
-      @messenger_threads_call += 1
+      @set_messenger_threads_call += 1
       @messenger_threads = messenger_threads
     end
 
     def messenger_queue_length=(messenger_queue_length)
-      @messenger_queue_length_call += 1
+      @set_messenger_queue_length_call += 1
       @messenger_queue_length = messenger_queue_length
     end
 
-    def subprocess_user=(subprocess_user)
-      @subprocess_user_call += 1
-      @subprocess_user = subprocess_user
+    def privilege
+      @privilege_call += 1
+      @privilege
     end
 
-    def subprocess_group=(subprocess_group)
-      @subprocess_group_call += 1
-      @subprocess_group = subprocess_group
+    def privilege=(privilege)
+      @set_privilege_call += 1
+      @privilege = privilege
     end
 
     def add_logger(logger)
@@ -308,14 +308,18 @@ module TestRucy
       nil
     end
 
+    # for Rucy::PasswordEncryptor
+
     def crypt(password)
       @crypt_call += 1
-      @pw_enc.crypt(password)
+      @pw_enc_orig.crypt(password)
     end
 
+    # for Rucy::DocumentLoader class
+
     def load
       @load_call += 1
-      @loader.load
+      @loader_orig.load
       nil
     end
 
@@ -326,24 +330,26 @@ module TestRucy
 
     def factory
       @factory_call += 1
-      @loader.factory
+      @loader_orig.factory
     end
 
     def RemoteAddressAllowAccessFilter
       @RemoteAddressAllowAccessFilter_call += 1
-      @loader.RemoteAddressAllowAccessFilter
+      @loader_orig.RemoteAddressAllowAccessFilter
     end
 
     def BasicAuthFilter
       @BasicAuthFilter_call += 1
-      @loader.BasicAuthFilter
+      @loader_orig.BasicAuthFilter
     end
 
+    # test
+
     def build_control
       @control = Rucy::Control.new
-      @control.loader = self
-      @control.pw_enc = self
-      @control.properties = self
+      @control.loader = @loader
+      @control.pw_enc = @pw_enc
+      @control.properties = @properties
       @control.page_path = 'nothing'
     end
     private :build_control
@@ -360,7 +366,7 @@ module TestRucy
 
     def test_server_restart
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(0, @restart_call)
       @control.server_restart
       @restart_signal.wait
@@ -369,7 +375,7 @@ module TestRucy
 
     def test_server_close
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(0, @close_call)
       @control.server_close
       @restart_signal.wait
@@ -379,6 +385,7 @@ module TestRucy
     def test_server_params
       build_control
       server_params = @control.server_params
+      assert_instance_of(Rucy::ServerParams, server_params)
       assert_equal(1, @params_call)
       @control.set_server_params(server_params)
       assert_equal(1, @set_params_call)
@@ -390,6 +397,7 @@ module TestRucy
     def test_logging_params
       build_control
       logging_params = @control.logging_params
+      assert_instance_of(Rucy::LoggingParams, logging_params)
       assert_equal(1, @params_call)
       @control.set_logging_params(logging_params)
       assert_equal(1, @set_params_call)
@@ -401,9 +409,12 @@ module TestRucy
     def test_aliases
       build_control
       alias_list = @control.aliases
+      assert_instance_of(Rucy::AliasList, alias_list)
       assert_equal(1, @list_call)
+      assert_equal('aliases', @list_name)
       @control.set_aliases(alias_list)
       assert_equal(1, @set_list_call)
+      assert_equal('aliases', @set_list_name)
       assert_exception(RuntimeError) {
 	@control.set_aliases(Array.new)
       }
@@ -411,147 +422,63 @@ module TestRucy
 
     def test_documents
       build_control
-      document_list = @control.documents
+      doc_list = @control.documents
+      assert_instance_of(Rucy::DocumentList, doc_list)
       assert_equal(1, @list_call)
-      assert_equal('documents', @list_last_name)
-      assert(document_list.empty?)
-      document_list.push({ 'document' => 'Page',
-			   'arguments' => [
-			     "Hello world.\n",
-			     'text/plain'
-			   ],
-			   'mount_path' => '/hello',
-			   'mount_mask' => nil,
-			   'virtual_host' => nil,
-			   'comment' => 'foo'
-			 })
-      document_list.push({ 'document' => 'LocalFile',
-			   'arguments' => [
-			     '/home/alice/public_html'
-			   ],
-			   'mount_path' => '/~alice',
-			   'mount_mask' => nil,
-			   'virtual_host' => 'foo',
-			   'comment' => 'bar'
-			 })
-      @control.set_documents(document_list)
+      assert_equal('documents', @list_name)
+      @control.set_documents(doc_list)
       assert_equal(1, @set_list_call)
-      assert_equal('documents', @set_list_last_name)
-      assert_equal(2, @properties['documents'].length)
-      assert_equal({ 'document' => 'Page',
-		     'arguments' => [
-		       "Hello world.\n",
-		       'text/plain'
-		     ],
-		     'mount_path' => '/hello',
-		     'mount_mask' => nil,
-		     'virtual_host' => nil,
-		     'comment' => 'foo'
-		   }, @properties['documents'][0])
-      assert_equal({ 'document' => 'LocalFile',
-		     'arguments' => [
-		       '/home/alice/public_html'
-		     ],
-		     'mount_path' => '/~alice',
-		     'mount_mask' => nil,
-		     'virtual_host' => 'foo',
-		     'comment' => 'bar'
-		   }, @properties['documents'][1])
+      assert_equal('documents', @set_list_name)
+      assert_exception(RuntimeError) {
+	@control.set_documents(Array.new)
+      }
     end
 
     def test_filters
       build_control
       filter_list = @control.filters
+      assert_instance_of(Rucy::FilterList, filter_list)
       assert_equal(1, @list_call)
-      assert_equal('filters', @list_last_name)
-      assert(filter_list.empty?)
-      filter_list.push({ 'filter' => 'ERB',
-			 'arguments' => [
-			   1
-			 ],
-			 'attach_path' => '/foo',
-			 'attach_mask' => %r"\.rhtml?($|/)",
-			 'virtual_host' => nil,
-			 'comment' => 'apple'
-		       })
-      filter_list.push({ 'filter' => 'SSI',
-			 'arguments' => [
-			   { 'config' => true,
-			     'include' => true,
-			     'echo' => true,
-			     'fsize' => true,
-			     'flastmod' => true,
-			     'exec' => true
-			   }
-			 ],
-			 'attach_path' => '/bar',
-			 'attach_mask' => %r"\.shtml?($|/)",
-			 'virtual_host' => 'baz',
-			 'comment' => 'banana'
-		       })
+      assert_equal('filters', @list_name)
       @control.set_filters(filter_list)
       assert_equal(1, @set_list_call)
-      assert_equal('filters', @set_list_last_name)
-      assert_equal(2, @properties['filters'].length)
-      assert_equal({ 'filter' => 'ERB',
-		     'arguments' => [
-		       1
-		     ],
-		     'attach_path' => '/foo',
-		     'attach_mask' => %r"\.rhtml?($|/)",
-		     'virtual_host' => nil,
-		     'comment' => 'apple'
-		   }, @properties['filters'][0])
-      assert_equal({ 'filter' => 'SSI',
-		     'arguments' => [
-		       { 'config' => true,
-			 'include' => true,
-			 'echo' => true,
-			 'fsize' => true,
-			 'flastmod' => true,
-			 'exec' => true
-		       }
-		     ],
-		     'attach_path' => '/bar',
-		     'attach_mask' => %r"\.shtml?($|/)",
-		     'virtual_host' => 'baz',
-		     'comment' => 'banana'
-		   }, @properties['filters'][1])
+      assert_equal('filters', @set_list_name)
     end
 
     def test_default_server_settings
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
+      assert_equal(1, @set_properties_privilege_call)
       assert_equal(4, @params_call) # for server parameters and logging parameters and access log parameters and admin parameters
       assert_equal(3, @list_call) # for (1) alias list and (2) document list and (3) filter list
       assert_equal(1, @load_call)
       assert_equal(1, @factory_call)
       assert_equal(1, @restart_signal_call)
       assert_instance_of(Rucy::MultiThreadRestartSignal, @restart_signal)
-      assert_equal(1, @port_call)
+      assert_equal(1, @set_port_call)
       assert_equal(8888, @port)
-      assert_equal(1, @bind_address_call)
-      assert_equal(nil, @bind_address)
-      assert_equal(1, @timeout_call)
+      assert_equal(1, @set_bind_address_call)
+      assert_equal('0.0.0.0', @bind_address)
+      assert_equal(1, @set_timeout_call)
       assert_equal(300, @timeout)
-      assert_equal(1, @keep_alive_call)
+      assert_equal(1, @set_keep_alive_call)
       assert_equal(8, @keep_alive)
-      assert_equal(1, @max_requests_call)
+      assert_equal(1, @set_max_requests_call)
       assert_equal(32, @max_requests)
-      assert_equal(1, @queue_length_call)
+      assert_equal(1, @set_queue_length_call)
       assert_equal(16, @queue_length)
-      assert_equal(1, @messengers_call)
+      assert_equal(1, @set_messengers_call)
       assert_equal(8, @messengers)
-      assert_equal(1, @messenger_factory_call)
+      assert_equal(1, @set_messenger_factory_call)
       assert_equal(Rucy::MultiThreadMessenger, @messenger_factory)
-      assert_equal(1, @messenger_threads_call)
+      assert_equal(1, @set_messenger_threads_call)
       assert_equal(4, @messenger_threads)
-      assert_equal(1, @messenger_queue_length_call)
+      assert_equal(1, @set_messenger_queue_length_call)
       assert_equal(4, @messenger_queue_length)
-      assert_equal(1, @subprocess_user_call)
-      assert_equal('nobody', @subprocess_user)
-      assert_equal(1, @subprocess_group_call)
-      assert_equal('nobody', @subprocess_group)
+      assert_equal(1, @set_privilege_call)
+      assert_equal('nobody', @privilege.non_privilege_user)
+      assert_equal('nobody', @privilege.non_privilege_group)
+      assert_equal(1, @privilege_call)
       assert_equal(1, @add_logger_call)
       assert_equal(1, @close_hook_call)
       assert_equal(1, @start_time_call)
@@ -573,50 +500,51 @@ module TestRucy
     end
 
     def test_modified_server_settings
-      @properties['server_type'] = 'multiprocess'
-      @properties['port'] = 80
-      @properties['bind_address'] = 'localhost'
-      @properties['timeout'] = 60
-      @properties['keep_alive'] = 4
-      @properties['max_requests'] = 24
-      @properties['queue_length'] = 32
-      @properties['messengers'] = 16
-      @properties['messenger_threads'] = 8
-      @properties['messenger_queue_length'] = 8
-      @properties['subprocess_user'] = 'httpd'
-      @properties['subprocess_group'] = 'httpd'
+      @store['server_type'] = 'multiprocess'
+      @store['port'] = 80
+      @store['bind_address'] = 'localhost'
+      @store['timeout'] = 60
+      @store['keep_alive'] = 4
+      @store['max_requests'] = 24
+      @store['queue_length'] = 32
+      @store['messengers'] = 16
+      @store['messenger_threads'] = 8
+      @store['messenger_queue_length'] = 8
+      @store['subprocess_user'] = 'httpd'
+      @store['subprocess_group'] = 'httpd'
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
+      assert_equal(1, @set_properties_privilege_call)
       assert_equal(4, @params_call) # for server parameters and logging parameters and access log parameters and admin parameters
       assert_equal(3, @list_call) # for (1) alias list and (2) document list and (3) filter list
       assert_equal(1, @load_call)
       assert_equal(1, @factory_call)
       assert_equal(1, @restart_signal_call)
       assert_instance_of(Rucy::MultiProcessRestartSignal, @restart_signal)
-      assert_equal(1, @port_call)
+      assert_equal(1, @set_port_call)
       assert_equal(80, @port)
-      assert_equal(1, @bind_address_call)
+      assert_equal(1, @set_bind_address_call)
       assert_equal('localhost', @bind_address)
-      assert_equal(1, @timeout_call)
+      assert_equal(1, @set_timeout_call)
       assert_equal(60, @timeout)
-      assert_equal(1, @keep_alive_call)
+      assert_equal(1, @set_keep_alive_call)
       assert_equal(4, @keep_alive)
-      assert_equal(1, @max_requests_call)
+      assert_equal(1, @set_max_requests_call)
       assert_equal(24, @max_requests)
-      assert_equal(1, @queue_length_call)
+      assert_equal(1, @set_queue_length_call)
       assert_equal(32, @queue_length)
-      assert_equal(1, @messengers_call)
+      assert_equal(1, @set_messengers_call)
       assert_equal(16, @messengers)
-      assert_equal(1, @messenger_factory_call)
+      assert_equal(1, @set_messenger_factory_call)
       assert_equal(Rucy::MultiProcessMessenger, @messenger_factory)
-      assert_equal(1, @messenger_threads_call)
+      assert_equal(1, @set_messenger_threads_call)
       assert_equal(8, @messenger_threads)
-      assert_equal(1, @messenger_queue_length_call)
+      assert_equal(1, @set_messenger_queue_length_call)
       assert_equal(8, @messenger_queue_length)
-      assert_equal(1, @subprocess_user_call)
-      assert_equal('httpd', @subprocess_user)
-      assert_equal(1, @subprocess_group_call)
-      assert_equal('httpd', @subprocess_group)
+      assert_equal(1, @set_privilege_call)
+      assert_equal('httpd', @privilege.non_privilege_user)
+      assert_equal('httpd', @privilege.non_privilege_group)
+      assert_equal(1, @privilege_call)
       assert_equal(1, @add_logger_call)
       assert_equal(1, @close_hook_call)
       assert_equal(1, @start_time_call)
@@ -641,7 +569,7 @@ module TestRucy
       build_control
       admin_params = @control.admin_params
       assert_equal(1, @params_call)
-      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @params_last_names.sort)
+      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @params_names.sort)
       assert_equal('admin', admin_params.admin_user)
       assert_equal('', admin_params.admin_password)
       assert_equal(true, admin_params.localhost_only)
@@ -652,38 +580,38 @@ module TestRucy
       build_control
       admin_params = @control.admin_params
       assert_equal(1, @params_call)
-      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @params_last_names.sort)
+      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @params_names.sort)
       assert_equal('admin', admin_params.admin_user)
       assert_equal('', admin_params.admin_password)
       assert_equal(true, admin_params.localhost_only)
       admin_params.localhost_only = false
       @control.set_admin_params(admin_params)
       assert_equal(1, @set_params_call)
-      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @set_params_last_names.sort)
-      assert_equal('admin', @properties['admin_user'])
-      assert_equal('', @properties['admin_password'])
-      assert_equal(true, @properties['localhost_only'])
-      admin_params.admin_password = @pw_enc.crypt('nazo')
+      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @set_params_names.sort)
+      assert_equal('admin', @store['admin_user'])
+      assert_equal('', @store['admin_password'])
+      assert_equal(true, @store['localhost_only'])
+      admin_params.admin_password = @pw_enc_orig.crypt('nazo')
       @control.set_admin_params(admin_params)
       assert_equal(2, @set_params_call)
-      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @set_params_last_names.sort)
-      assert_equal('admin', @properties['admin_user'])
-      assert(@properties['admin_password'] != 'nazo')
-      assert(@properties['admin_password'] == @pw_enc.crypt('nazo', @properties['admin_password']))
-      assert_equal(true, @properties['localhost_only'])
+      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @set_params_names.sort)
+      assert_equal('admin', @store['admin_user'])
+      assert(@store['admin_password'] != 'nazo')
+      assert(@store['admin_password'] == @pw_enc_orig.crypt('nazo', @store['admin_password']))
+      assert_equal(true, @store['localhost_only'])
       admin_params.localhost_only = false
       @control.set_admin_params(admin_params)
       assert_equal(3, @set_params_call)
-      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @set_params_last_names.sort)
-      assert_equal('admin', @properties['admin_user'])
-      assert(@properties['admin_password'] != 'nazo')
-      assert(@properties['admin_password'] == @pw_enc.crypt('nazo', @properties['admin_password']))
-      assert_equal(false, @properties['localhost_only'])
+      assert_equal(%w[ admin_password admin_user japanese_handling localhost_only ], @set_params_names.sort)
+      assert_equal('admin', @store['admin_user'])
+      assert(@store['admin_password'] != 'nazo')
+      assert(@store['admin_password'] == @pw_enc_orig.crypt('nazo', @store['admin_password']))
+      assert_equal(false, @store['localhost_only'])
     end
 
     def test_ControlPanel_document
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(1, @load_call)
       assert_equal(1, @factory_call)
       assert_equal(1, @RemoteAddressAllowAccessFilter_call)
@@ -694,17 +622,17 @@ module TestRucy
       assert_equal(0, @virtual_attach_call)
       document = @folder.find('/control')[0]
       assert_instance_of(Rucy::FilterDocument, document)
-      assert_instance_of(@loader.RemoteAddressAllowAccessFilter, document.filter)
+      assert_instance_of(@loader_orig.RemoteAddressAllowAccessFilter, document.filter)
       assert_instance_of(Rucy::WebPageMakerDocument, document.document)
       assert_equal('/control', @folder.find('/control')[1])
     end
 
     def test_ControlPanel_with_BasicAuth
-      @properties['admin_user'] = 'admin'
-      @properties['admin_password'] = @pw_enc.crypt('nazo')
-      @properties['localhost_only'] = false
+      @store['admin_user'] = 'admin'
+      @store['admin_password'] = @pw_enc_orig.crypt('nazo')
+      @store['localhost_only'] = false
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(1, @load_call)
       assert_equal(1, @factory_call)
       assert_equal(0, @RemoteAddressAllowAccessFilter_call)
@@ -715,17 +643,17 @@ module TestRucy
       assert_equal(0, @virtual_attach_call)
       document = @folder.find('/control')[0]
       assert_instance_of(Rucy::FilterDocument, document)
-      assert_instance_of(@loader.BasicAuthFilter, document.filter)
+      assert_instance_of(@loader_orig.BasicAuthFilter, document.filter)
       assert_instance_of(Rucy::WebPageMakerDocument, document.document)
       assert_equal('/control', @folder.find('/control')[1])
     end
 
     def test_ControlPanel_with_BasicAuth_and_LocalhostOnly
-      @properties['admin_user'] = 'admin'
-      @properties['admin_password'] = @pw_enc.crypt('nazo')
-      @properties['localhost_only'] = true
+      @store['admin_user'] = 'admin'
+      @store['admin_password'] = @pw_enc_orig.crypt('nazo')
+      @store['localhost_only'] = true
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(1, @load_call)
       assert_equal(1, @factory_call)
       assert_equal(1, @RemoteAddressAllowAccessFilter_call)
@@ -736,17 +664,17 @@ module TestRucy
       assert_equal(0, @virtual_attach_call)
       document = @folder.find('/control')[0]
       assert_instance_of(Rucy::FilterDocument, document)
-      assert_instance_of(@loader.BasicAuthFilter, document.filter)
+      assert_instance_of(@loader_orig.BasicAuthFilter, document.filter)
       document = document.document
       assert_instance_of(Rucy::FilterDocument, document)
-      assert_instance_of(@loader.RemoteAddressAllowAccessFilter, document.filter)
+      assert_instance_of(@loader_orig.RemoteAddressAllowAccessFilter, document.filter)
       assert_instance_of(Rucy::WebPageMakerDocument, document.document)
       assert_equal('/control', @folder.find('/control')[1])
     end
 
     def test_logging_setup
-      @properties['stdout_logging_level'] = 'info'
-      @properties['logfiles'] = [
+      @store['stdout_logging_level'] = 'info'
+      @store['logfiles'] = [
 	{ 'path' => 'server.log',
 	  'logging_level' => 'notice'
 	},
@@ -760,7 +688,7 @@ module TestRucy
 
       begin
 	build_control
-	@control.server_setup(self)
+	@control.server_setup(@server)
 	assert_equal(4, @add_logger_call)
 	assert((File.file? 'server.log'))
 	assert((File.file? 'access.log'))
@@ -779,13 +707,13 @@ module TestRucy
     end
 
     def test_logging_errors
-      @properties['logfiles'] = [
+      @store['logfiles'] = [
 	{ 'path' => 'detarame/server.log',
 	  'logging_level' => 'notice'
 	}
       ]
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(1, @add_logger_call)
       assert_equal(1, @control.logging_errors.length)
       assert_equal('detarame/server.log', @control.logging_errors[0][:logfile])
@@ -793,7 +721,7 @@ module TestRucy
     end
 
     def test_alias_setup
-      @properties['aliases'] = [
+      @store['aliases'] = [
 	{ 'virtual_host' => nil,
 	  'alias_path' => '/bar',
 	  'orig_path' => '/foo'
@@ -804,7 +732,7 @@ module TestRucy
 	}
       ]
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(1, @set_alias_call)
       assert_equal([ [ '/bar', '/foo' ] ], @set_alias_alist)
       assert_equal(1, @set_virtual_alias_call)
@@ -812,14 +740,14 @@ module TestRucy
     end
 
     def test_alias_setup_error
-      @properties['aliases'] = [
+      @store['aliases'] = [
 	{ 'virtual_host' => nil,
 	  'alias_path' => 'bar',
 	  'orig_path' => 'foo'
 	}
       ]
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(1, @set_alias_call)
       assert_equal(1, @control.alias_errors.length)
       assert_equal(nil, @control.alias_errors[0][:virtual_host])
@@ -829,7 +757,7 @@ module TestRucy
     end
 
     def test_document_setup
-      @properties['documents'] = [
+      @store['documents'] = [
 	{ 'document' => 'Page',
 	  'arguments' => [
 	    "Hello world.\n",
@@ -850,12 +778,12 @@ module TestRucy
 	}
       ]
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(2, @mount_call)
       assert_equal(1, @virtual_mount_call)
-      assert_instance_of(@loader.PageDocument, @folder.find('/hello')[0])
+      assert_instance_of(@loader_orig.PageDocument, @folder.find('/hello')[0])
       assert_equal('/hello', @folder.find('/hello')[1])
-      assert_instance_of(@loader.LocalFileDocument, @folder.virtual_find('foo:8888', '/~alice')[0])
+      assert_instance_of(@loader_orig.LocalFileDocument, @folder.virtual_find('foo:8888', '/~alice')[0])
       assert_equal('/~alice', @folder.virtual_find('foo:8888', '/~alice')[1])
     end
 
@@ -878,7 +806,7 @@ module TestRucy
 # 	end
 #       end
 #       @factory.add_document(error)
-#       @properties['documents'] = [
+#       @store['documents'] = [
 # 	{ 'document' => 'TestError',
 # 	  'arguments' => [],
 # 	  'mount_path' => '/error',
@@ -887,7 +815,7 @@ module TestRucy
 # 	}
 #       ]
 #       build_control
-#       @control.server_setup(self)
+#       @control.server_setup(@server)
 #       assert_equal(1, @mount_call)
 #       assert_equal(0, @virtual_mount_call)
 #       assert_nil(@folder.find('/error'))
@@ -902,7 +830,7 @@ module TestRucy
 #     end
 
     def test_filter_setup
-      @properties['documents'] = [
+      @store['documents'] = [
 	{ 'document' => 'Page',
 	  'arguments' => [
 	    "Hello world.\n",
@@ -922,7 +850,7 @@ module TestRucy
 	  'virtual_host' => 'baz'
 	}
       ]
-      @properties['filters'] = [
+      @store['filters'] = [
 	{ 'filter' => 'ERB',
 	  'arguments' => [ '1', false ],
 	  'attach_path' => '/foo',
@@ -937,17 +865,17 @@ module TestRucy
 	}
       ]
       build_control
-      @control.server_setup(self)
+      @control.server_setup(@server)
       assert_equal(2, @attach_call)
       assert_equal(1, @virtual_attach_call)
-      assert_instance_of(@loader.ERBFilter, @folder.find('/foo/index.rhtml')[0].filter)
+      assert_instance_of(@loader_orig.ERBFilter, @folder.find('/foo/index.rhtml')[0].filter)
       assert_equal('/foo', @folder.find('/foo/index.rhtml')[1])
-      assert_instance_of(@loader.ERBFilter, @folder.virtual_find('baz:8888', '/bar/index.rhtml')[0].filter)
+      assert_instance_of(@loader_orig.ERBFilter, @folder.virtual_find('baz:8888', '/bar/index.rhtml')[0].filter)
       assert_equal('/bar', @folder.virtual_find('baz:8888', '/bar/index.shtml')[1])
     end
 
 #     def test_filter_setup_error
-#       @properties['documents'] = [
+#       @store['documents'] = [
 # 	{ 'document' => 'Page',
 # 	  'arguments' => [
 # 	    "Hello world.\n",
@@ -985,7 +913,7 @@ module TestRucy
 # 	end
 #       end
 #       @factory.add_filter(error)
-#       @properties['filters'] = [
+#       @store['filters'] = [
 # 	{ 'filter' => 'TestError',
 # 	  'arguments' => [],
 # 	  'attach_path' => '/error',
@@ -994,7 +922,7 @@ module TestRucy
 # 	}
 #       ]
 #       build_control
-#       @control.server_setup(self)
+#       @control.server_setup(@server)
 #       assert_equal(1, @attach_call)
 #       assert_equal(0, @virtual_attach_call)
 #       assert_equal(1, @control.filter_errors.length)
