@@ -1,8 +1,9 @@
 #!/usr/local/bin/ruby
-# $Id: test_document.rb,v 1.6 2004/10/02 00:42:02 toki Exp $
+# $Id: test_document.rb,v 1.8 2004/12/12 00:20:34 toki Exp $
 
 require 'singleton'
 require 'rubyunit'
+require 'forwarder'
 require 'pseudo_req_res'
 require 'rucy/request'
 require 'rucy/response'
@@ -44,7 +45,7 @@ module TestRucy
 
     def setup
       super
-      @filter_document = Rucy::FilterDocument.new(self, self)
+      @filter_document = Rucy::FilterDocument.new(@document, @filter)
     end
 
     def test_filter_init
@@ -58,7 +59,7 @@ module TestRucy
     end
 
     def test_each
-      doc_list = [ @filter_document, self ]
+      doc_list = [ @filter_document, @document ]
       for doc in @filter_document
 	assert(doc_list.delete(doc))
       end
@@ -133,7 +134,7 @@ module TestRucy
 
     def setup
       super
-      @filter_document = Rucy::FilterDocument.new(self, FilterTermination.new(self))
+      @filter_document = Rucy::FilterDocument.new(@document, FilterTermination.new(@filter))
     end
 
     def test_GET
@@ -156,21 +157,48 @@ module TestRucy
 
   class TestDocumentFactory < RUNIT::TestCase
     def setup
+      # for Rucy::DocumentBuilder class
       @doc_name_call = 0
       @doc_args_call = 0
       @set_doc_option_call = 0
       @set_doc_option_value = nil
+      @doc_new_call = 0
+      @doc_new_string_value = nil
+      @doc_new_text_value = nil
+      @doc_new_number_value = nil
+
+      @doc_builder = Forwarder.new(self)
+      class << @doc_builder
+	def_delegator :__getobj__, :doc_name
+	def_delegator :__getobj__, :doc_args
+	def_delegator :__getobj__, :set_doc_option
+	def_delegator :__getobj__, :doc_new, :new
+      end
+
+      # for Rucy::FilterBuilder class
       @filter_name_call = 0
       @filter_args_call = 0
       @set_filter_option_call = 0
       @set_filter_option_value = nil
-      @new_call = 0
-      @new_string_value = nil
-      @new_text_value = nil
-      @new_number_value = nil
+      @filter_new_call = 0
+      @filter_new_string_value = nil
+      @filter_new_text_value = nil
+      @filter_new_number_value = nil
+
+      @filter_builder = Forwarder.new(self)
+      class << @filter_builder
+	def_delegator :__getobj__, :filter_name
+	def_delegator :__getobj__, :filter_args
+	def_delegator :__getobj__, :set_filter_option
+	def_delegator :__getobj__, :filter_new, :new
+      end
+
+      # target
       @factory = Rucy::DocumentFactory.new
     end
 
+    # for Rucy::DocumentBuilder class
+
     def doc_name
       @doc_name_call += 1
       'test_document'
@@ -197,6 +225,16 @@ module TestRucy
       nil
     end
 
+    def doc_new(string, text, number)
+      @doc_new_call += 1
+      @doc_new_string_value = string
+      @doc_new_text_value = text
+      @doc_new_number_value = number
+      :test_document
+    end
+
+    # for Rucy::FilterBuilder class
+
     def filter_name
       @filter_name_call += 1
       'test_filter'
@@ -223,19 +261,21 @@ module TestRucy
       nil
     end
 
-    def new(string, text, number)
-      @new_call += 1
-      @new_string_value = string
-      @new_text_value = text
-      @new_number_value = number
-      :test
+    def filter_new(string, text, number)
+      @filter_new_call += 1
+      @filter_new_string_value = string
+      @filter_new_text_value = text
+      @filter_new_number_value = number
+      :test_filter
     end
 
+    # test
+
     def test_setup
       @factory.add_option(:foo, 'apple')
       @factory.add_option(:bar, 'banana')
-      @factory.add_document(self)
-      @factory.add_filter(self)
+      @factory.add_document(@doc_builder)
+      @factory.add_filter(@filter_builder)
       @factory.setup
       assert_equal(1, @set_doc_option_call)
       assert_equal('apple', @set_doc_option_value[:foo])
@@ -247,12 +287,12 @@ module TestRucy
 
     def test_has_document?
       assert(! (@factory.has_document? 'test_document'))
-      @factory.add_document(self)
+      @factory.add_document(@doc_builder)
       assert((@factory.has_document? 'test_document'))
     end
 
     def test_doc_names
-      @factory.add_document(self)
+      @factory.add_document(@doc_builder)
       assert_equal(1, @doc_name_call)
       doc_names = @factory.doc_names
       assert_equal(1, doc_names.length)
@@ -260,7 +300,7 @@ module TestRucy
     end
 
     def test_doc_args
-      @factory.add_document(self)
+      @factory.add_document(@doc_builder)
       assert_equal(1, @doc_name_call)
       doc_args = @factory.doc_args('test_document')
       assert_equal(1, @doc_args_call)
@@ -280,24 +320,24 @@ module TestRucy
     end
 
     def test_doc_build
-      @factory.add_document(self)
+      @factory.add_document(@doc_builder)
       assert_equal(1, @doc_name_call)
       dummy_doc = @factory.doc_build('test_document', [ 'string', 'text', 0 ])
-      assert_equal(1, @new_call)
-      assert_equal('string', @new_string_value)
-      assert_equal('text', @new_text_value)
-      assert_equal(0, @new_number_value)
-      assert_equal(:test, dummy_doc)
+      assert_equal(1, @doc_new_call)
+      assert_equal('string', @doc_new_string_value)
+      assert_equal('text', @doc_new_text_value)
+      assert_equal(0, @doc_new_number_value)
+      assert_equal(:test_document, dummy_doc)
     end
 
     def test_has_filter?
       assert(! (@factory.has_filter? 'test_filter'))
-      @factory.add_filter(self)
+      @factory.add_filter(@filter_builder)
       assert((@factory.has_filter? 'test_filter'))
     end
 
     def test_filter_names
-      @factory.add_filter(self)
+      @factory.add_filter(@filter_builder)
       assert_equal(1, @filter_name_call)
       filter_names = @factory.filter_names
       assert_equal(1, filter_names.length)
@@ -305,7 +345,7 @@ module TestRucy
     end
 
     def test_filter_args
-      @factory.add_filter(self)
+      @factory.add_filter(@filter_builder)
       assert_equal(1, @filter_name_call)
       filter_args = @factory.filter_args('test_filter')
       assert_equal(1, @filter_args_call)
@@ -325,14 +365,14 @@ module TestRucy
     end
 
     def test_filter_build
-      @factory.add_filter(self)
+      @factory.add_filter(@filter_builder)
       assert_equal(1, @filter_name_call)
       dummy_filter = @factory.filter_build('test_filter', [ 'string', 'text', 0 ])
-      assert_equal(1, @new_call)
-      assert_equal('string', @new_string_value)
-      assert_equal('text', @new_text_value)
-      assert_equal(0, @new_number_value)
-      assert_equal(:test, dummy_filter)
+      assert_equal(1, @filter_new_call)
+      assert_equal('string', @filter_new_string_value)
+      assert_equal('text', @filter_new_text_value)
+      assert_equal(0, @filter_new_number_value)
+      assert_equal(:test_filter, dummy_filter)
     end
   end
 
@@ -396,10 +436,7 @@ module TestRucy
 	output.print "include Rucy\n"
 	output.print "class FooDocument < Document\n"
 	output.print "end\n"
-	output.print "class FooDocumentFactory\n"
-	output.print "  include Singleton\n"
-	output.print "  def set_doc_option(opts)\n"
-	output.print "  end\n"
+	output.print "class FooDocumentBuilder < DocumentBuilder\n"
 	output.print "  def doc_name\n"
 	output.print "    'Foo'\n"
 	output.print "  end\n"
@@ -415,10 +452,7 @@ module TestRucy
 	output.print "include Rucy\n"
 	output.print "class BarFilter < Filter\n"
 	output.print "end\n"
-	output.print "class BarFilterFactory\n"
-	output.print "  include Singleton\n"
-	output.print "  def set_filter_option(opts)\n"
-	output.print "  end\n"
+	output.print "class BarFilterBuilder < FilterBuilder\n"
 	output.print "  def filter_name\n"
 	output.print "    'Bar'\n"
 	output.print "  end\n"
@@ -572,11 +606,11 @@ module TestRucy
 
     def setup
       super
-      @doc = Rucy::SubsetDocument.new(self, '/foo')
+      @doc = Rucy::SubsetDocument.new(@document, '/foo')
     end
 
     def test_each
-      doc_list = [ @doc, self ]
+      doc_list = [ @doc, @document ]
       for doc in @doc
 	assert(doc_list.delete(doc))
       end
@@ -657,19 +691,19 @@ module TestRucy
     end
 
     def test_umount
-      @folder.mount(self, '/foo')
-      assert_equal(self, @folder.find('/foo')[0])
+      @folder.mount(@document, '/foo')
+      assert_equal(@document, @folder.find('/foo')[0])
       assert_equal('/foo', @folder.find('/foo')[1])
-      assert_equal(self, @folder.find('/foo/bar')[0])
+      assert_equal(@document, @folder.find('/foo/bar')[0])
       assert_equal('/foo', @folder.find('/foo/bar')[1])
-      assert_equal(self, @folder.umount('/foo'))
+      assert_equal(@document, @folder.umount('/foo'))
       assert_nil(@folder.find('/foo'))
 
-      @folder.mount(self, '/foo', /\.cgi/)
+      @folder.mount(@document, '/foo', /\.cgi/)
       assert_nil(@folder.find('/foo/bar'))
-      assert_equal(self, @folder.find('/foo/bar.cgi')[0])
+      assert_equal(@document, @folder.find('/foo/bar.cgi')[0])
       assert_equal('/foo', @folder.find('/foo/bar.cgi')[1])
-      assert_equal(self, @folder.umount('/foo', /\.cgi/))
+      assert_equal(@document, @folder.umount('/foo', /\.cgi/))
       assert_nil(@folder.find('/foo/bar.cgi'))
     end
 
@@ -677,8 +711,8 @@ module TestRucy
       folder2 = Rucy::FolderDocument.new
       @folder.mount(folder2, '/foo')
       folder2.mount(@folder, '/bar')
-      @folder.mount(self, '/')
-      doc_list = [ @folder, folder2, self ]
+      @folder.mount(@document, '/')
+      doc_list = [ @folder, folder2, @document ]
       for doc in @folder
 	assert(doc_list.delete(doc))
       end
@@ -686,7 +720,7 @@ module TestRucy
     end
 
     def test_GET_root
-      @folder.mount(self, '/')
+      @folder.mount(@document, '/')
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
@@ -703,7 +737,7 @@ module TestRucy
     end
 
     def test_GET_root_foo
-      @folder.mount(self, '/')
+      @folder.mount(@document, '/')
       @request.method = 'GET'
       @request.path = '/foo'
       @request.version = 'HTTP/1.1'
@@ -720,7 +754,7 @@ module TestRucy
     end
 
     def test_GET_foo
-      @folder.mount(self, '/foo')
+      @folder.mount(@document, '/foo')
       @request.method = 'GET'
       @request.path = '/foo'
       @request.version = 'HTTP/1.1'
@@ -737,7 +771,7 @@ module TestRucy
     end
 
     def test_GET_foo_bar
-      @folder.mount(self, '/foo')
+      @folder.mount(@document, '/foo')
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
@@ -754,7 +788,7 @@ module TestRucy
     end
 
     def test_GET_foo_not_found
-      @folder.mount(self, '/foo')
+      @folder.mount(@document, '/foo')
       @request.method = 'GET'
       @request.path = '/bar'
       @request.version = 'HTTP/1.1'
@@ -771,7 +805,7 @@ module TestRucy
     end
 
     def tset_GET_mask
-      @folder.mount(self, '/', /\.cgi/)
+      @folder.mount(@document, '/', /\.cgi/)
       @request.method = 'GET'
       @request.path = '/foo.cgi'
       @request.version = 'HTTP/1.1'
@@ -788,7 +822,7 @@ module TestRucy
     end
 
     def test_GET_mask_not_found
-      @folder.mount(self, '/', /\.cgi/)
+      @folder.mount(@document, '/', /\.cgi/)
       @request.method = 'GET'
       @request.path = '/foo.html'
       @request.version = 'HTTP/1.1'
@@ -805,8 +839,8 @@ module TestRucy
     end
 
     def test_GET_filter
-      @folder.mount(self, '/foo')
-      @folder.attach(self, '/foo')
+      @folder.mount(@document, '/foo')
+      @folder.attach(@filter, '/foo')
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
@@ -835,8 +869,8 @@ module TestRucy
     end
 
     def test_GET_filter2
-      @folder.mount(self, '/foo')
-      @folder.attach(self, '/foo/bar')
+      @folder.mount(@document, '/foo')
+      @folder.attach(@filter, '/foo/bar')
       @request.method = 'GET'
       @request.path = '/foo/bar/baz'
       @request.version = 'HTTP/1.1'
@@ -865,8 +899,8 @@ module TestRucy
     end
 
     def test_GET_filter_mask
-      @folder.mount(self, '/foo')
-      @folder.attach(self, '/foo', /\.cgi/)
+      @folder.mount(@document, '/foo')
+      @folder.attach(@filter, '/foo', /\.cgi/)
       @request.method = 'GET'
       @request.path = '/foo/bar.cgi'
       @request.version = 'HTTP/1.1'
@@ -895,8 +929,8 @@ module TestRucy
     end
 
     def test_GET_filter_mask2
-      @folder.mount(self, '/foo')
-      @folder.attach(self, '/foo', /\.cgi/)
+      @folder.mount(@document, '/foo')
+      @folder.attach(@filter, '/foo', /\.cgi/)
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
@@ -919,7 +953,7 @@ module TestRucy
     end
 
     def test_GET_virtual
-      @folder.virtual_mount('foo', self, '/')
+      @folder.virtual_mount('foo', @document, '/')
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
@@ -937,7 +971,7 @@ module TestRucy
     end
 
     def test_GET_virtual_not_found
-      @folder.virtual_mount('foo', self, '/')
+      @folder.virtual_mount('foo', @document, '/')
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
@@ -954,7 +988,7 @@ module TestRucy
     end
 
     def test_GET_virtual_mask
-      @folder.virtual_mount('foo', self, '/', /\.cgi/)
+      @folder.virtual_mount('foo', @document, '/', /\.cgi/)
       @request.method = 'GET'
       @request.path = '/foo.cgi'
       @request.version = 'HTTP/1.1'
@@ -972,7 +1006,7 @@ module TestRucy
     end
 
     def test_GET_virtual_mask_not_found
-      @folder.virtual_mount('foo', self, '/', /\.cgi/)
+      @folder.virtual_mount('foo', @document, '/', /\.cgi/)
       @request.method = 'GET'
       @request.path = '/foo.cgi'
       @request.version = 'HTTP/1.1'
@@ -989,8 +1023,8 @@ module TestRucy
     end
 
     def test_GET_virtual_filter
-      @folder.virtual_mount('foo', self, '/foo')
-      @folder.virtual_attach('foo', self, '/foo')
+      @folder.virtual_mount('foo', @document, '/foo')
+      @folder.virtual_attach('foo', @filter, '/foo')
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
@@ -1020,8 +1054,8 @@ module TestRucy
     end
 
     def test_GET_virtual_filter_not_found
-      @folder.virtual_mount('foo', self, '/foo')
-      @folder.virtual_attach('foo', self, '/foo')
+      @folder.virtual_mount('foo', @document, '/foo')
+      @folder.virtual_attach('foo', @document, '/foo')
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
@@ -1043,7 +1077,7 @@ module TestRucy
 
     def test_alias_root
       @folder.set_alias('/foo', '/')	# /foo -> /
-      @folder.mount(self, '/')
+      @folder.mount(@document, '/')
       @request.method = 'GET'
       @request.path = '/foo'
       @request.version = 'HTTP/1.1'
@@ -1061,7 +1095,7 @@ module TestRucy
 
     def test_alias_root2
       @folder.set_alias('/', '/foo')	# / -> /foo
-      @folder.mount(self, '/foo')
+      @folder.mount(@document, '/foo')
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
@@ -1079,7 +1113,7 @@ module TestRucy
 
     def test_alias_foo
       @folder.set_alias('/bar', '/foo')	# /bar -> /foo
-      @folder.mount(self, '/foo')
+      @folder.mount(@document, '/foo')
       @request.method = 'GET'
       @request.path = '/bar'
       @request.version = 'HTTP/1.1'
@@ -1097,7 +1131,7 @@ module TestRucy
 
     def test_virtual_alias_root
       @folder.set_virtual_alias('baz', '/foo', '/') # /foo -> /
-      @folder.virtual_mount('baz', self, '/')
+      @folder.virtual_mount('baz', @document, '/')
       @request.method = 'GET'
       @request.path = '/foo'
       @request.version = 'HTTP/1.1'
@@ -1116,7 +1150,7 @@ module TestRucy
 
     def test_virtual_alias_root2
       @folder.set_virtual_alias('baz', '/', '/foo') # / -> /foo
-      @folder.virtual_mount('baz', self, '/foo')
+      @folder.virtual_mount('baz', @document, '/foo')
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
@@ -1135,7 +1169,7 @@ module TestRucy
 
     def test_virtual_alias_foo
       @folder.set_virtual_alias('baz', '/bar', '/foo') # /bar -> /foo
-      @folder.virtual_mount('baz', self, '/foo')
+      @folder.virtual_mount('baz', @document, '/foo')
       @request.method = 'GET'
       @request.path = '/bar'
       @request.version = 'HTTP/1.1'
