@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test_erb.rb,v 1.3 2004/09/29 14:55:59 toki Exp $
+# $Id: test_erb.rb,v 1.4 2004/10/30 09:01:07 toki Exp $
 
 require 'rubyunit'
 require 'pseudo_req_res'
@@ -158,30 +158,30 @@ __logger__.debug("Hello world.")
     end
   end
 
-  class TestERBFilterFactory < RUNIT::TestCase
+  class TestERBFilterBuilder < RUNIT::TestCase
     def setup
       @loader = Rucy::SimpleLoader.new
       @loader.load('../mod_docs/erb.rb')
-      @ERBFilterFactory = @loader.const_get('ERBFilterFactory')
-      @factory = @ERBFilterFactory.instance
+      @ERBFilterBuilder = @loader.const_get('ERBFilterBuilder')
+      @builder = @ERBFilterBuilder.instance
     end
 
     def test_set_filter_option
-      @factory.set_filter_option(Hash.new)
+      @builder.set_filter_option(Hash.new)
     end
 
     def test_filter_name
-      assert_equal('ERB', @factory.filter_name)
+      assert_equal('ERB', @builder.filter_name)
     end
 
     def test_filter_args
-      args = @factory.filter_args
+      args = @builder.filter_args
       assert_equal([ 'safe level', :select, %w[ 1 2 3 4 0 ] ], args[0])
       assert_equal([ 'pass auth', :bool, false ], args[1])
     end
 
     def test_new
-      filter = @factory.new('1', false)
+      filter = @builder.new('1', false)
       assert_instance_of(@loader.const_get('ERBFilter'), filter)
     end
   end
