@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test_lang.rb,v 1.8 2004/09/29 15:00:53 toki Exp $
+# $Id: test_lang.rb,v 1.9 2004/10/30 09:01:10 toki Exp $
 
 require 'rubyunit'
 require 'pseudo_req_res'
@@ -149,24 +149,24 @@ module TestRucy
     end
   end
 
-  class TestLanguageRedirectFilterFactory < RUNIT::TestCase
+  class TestLanguageRedirectFilterBuilder < RUNIT::TestCase
     def setup
       @loader = Rucy::SimpleLoader.new
       @loader.load('../mod_docs/lang.rb')
-      @LanguageRedirectFilterFactory = @loader.const_get('LanguageRedirectFilterFactory')
-      @factory = @LanguageRedirectFilterFactory.instance
+      @LanguageRedirectFilterBuilder = @loader.const_get('LanguageRedirectFilterBuilder')
+      @builder = @LanguageRedirectFilterBuilder.instance
     end
 
     def test_set_filter_option
-      @factory.set_filter_option(Hash.new)
+      @builder.set_filter_option(Hash.new)
     end
 
     def test_filter_name
-      assert_equal('LanguageRedirect', @factory.filter_name)
+      assert_equal('LanguageRedirect', @builder.filter_name)
     end
 
     def test_filter_args
-      args = @factory.filter_args
+      args = @builder.filter_args
       assert_equal([ 'status', :select, [
 		       '302 Found',
 		       '303 See Other',
@@ -187,7 +187,7 @@ module TestRucy
     end
 
     def test_new
-      filter = @factory.new('302 Found',
+      filter = @builder.new('302 Found',
 			    nil, nil,
 			    nil, nil,
 			    nil, nil,
