@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test_local.rb,v 1.4 2004/10/02 01:00:18 toki Exp $
+# $Id: test_local.rb,v 1.6 2004/12/12 00:20:38 toki Exp $
 
 require 'rubyunit'
 require 'time'
@@ -72,7 +72,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      @dir_doc.publish('', @request, @response, self)
+      @dir_doc.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -92,7 +92,7 @@ module TestRucy
       @request.method = 'HEAD'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      @dir_doc.publish('', @request, @response, self)
+      @dir_doc.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -114,7 +114,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@dir_doc.publish('', @request, @response, self)
+	@dir_doc.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(405, $!.status)
 	assert_equal('GET, HEAD', $!.header('Allow'))
@@ -139,7 +139,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@dir_doc.publish('', @request, @response, self)
+	@dir_doc.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(404, $!.status)
 	done = true
@@ -161,7 +161,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/subdir/'
       @request.version = 'HTTP/1.1'
-      @dir_doc.publish('', @request, @response, self)
+      @dir_doc.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -182,7 +182,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@dir_doc.publish('', @request, @response, self)
+	@dir_doc.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(404, $!.status)
 	done = true
@@ -238,7 +238,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -261,7 +261,7 @@ module TestRucy
       @request.method = 'HEAD'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -286,7 +286,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@local_doc.publish('', @request, @response, self)
+	@local_doc.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(405, $!.status)
 	assert_equal('GET, HEAD', $!.header('Allow'))
@@ -309,7 +309,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -332,7 +332,7 @@ module TestRucy
       @request.method = 'HEAD'
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -357,7 +357,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@local_doc.publish('', @request, @response, self)
+	@local_doc.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(405, $!.status)
 	assert_equal('GET, HEAD', $!.header('Allow'))
@@ -382,7 +382,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@local_doc.publish('', @request, @response, self)
+	@local_doc.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(404, $!.status) # 404 Not Found
 	done = true
@@ -404,7 +404,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/subdir'
       @request.version = 'HTTP/1.1'
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/subdir', @messg_head.doc_path)
       assert_match(@response.local_path, %r"test/subdir$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -425,7 +425,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/subdir/'
       @request.version = 'HTTP/1.1'
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/subdir/', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/subdir$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -447,7 +447,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/subdir/foo'
       @request.version = 'HTTP/1.1'
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/subdir/foo', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/subdir/foo$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -471,7 +471,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@local_doc.publish('', @request, @response, self)
+	@local_doc.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(403, $!.status) # Forbidden
 	done = true
@@ -495,7 +495,7 @@ module TestRucy
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
       @request.set_header('If-Modified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -519,7 +519,7 @@ module TestRucy
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
       @request.set_header('If-Modified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -545,7 +545,7 @@ module TestRucy
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
       @request.set_header('If-Unmodified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -568,7 +568,7 @@ module TestRucy
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
       @request.set_header('If-Unmodified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -592,7 +592,7 @@ module TestRucy
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=7-')
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -617,7 +617,7 @@ module TestRucy
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=1024-')
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -639,7 +639,7 @@ module TestRucy
       @request.path = '/index.html'
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=-1024') # invalid range spec.
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -666,7 +666,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=7-')
       @request.set_header('If-Modified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -691,7 +691,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=7-')
       @request.set_header('If-Modified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -719,7 +719,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=7-')
       @request.set_header('If-Unmodified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -743,7 +743,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=7-')
       @request.set_header('If-Unmodified-Since', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -770,7 +770,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=7-')
       @request.set_header('If-Range', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -798,7 +798,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       @request.set_header('Range', 'bytes=7-')
       @request.set_header('If-Range', mtime.httpdate)
-      @local_doc.publish('', @request, @response, self)
+      @local_doc.publish('', @request, @response, @logger)
       assert_equal('/index.html', @messg_head.doc_path)
       assert_match(@messg_head.local_path, %r"test/index\.html$")
       assert_equal('HTTP/1.1', @messg_head.version)
@@ -819,24 +819,24 @@ module TestRucy
     end
   end
 
-  class TestLocalFileDocumentFactory < RUNIT::TestCase
+  class TestLocalFileDocumentBuilder < RUNIT::TestCase
     def setup
       @loader = Rucy::SimpleLoader.new
       @loader.load('../mod_docs/local.rb')
-      @LocalFileDocumentFactory = @loader.const_get('LocalFileDocumentFactory')
-      @factory = @LocalFileDocumentFactory.instance
+      @LocalFileDocumentBuilder = @loader.const_get('LocalFileDocumentBuilder')
+      @builder = @LocalFileDocumentBuilder.instance
     end
 
     def test_set_doc_option
-      @factory.set_doc_option(Hash.new)
+      @builder.set_doc_option(Hash.new)
     end
 
     def tset_doc_name
-      assert_equal('LocalFile', @factory.doc_name)
+      assert_equal('LocalFile', @builder.doc_name)
     end
 
     def test_doc_args
-      args = @factory.doc_args
+      args = @builder.doc_args
       assert_equal([ 'local path', :string, nil ], args[0])
       assert_equal([ 'default content-type (optional)', :string, nil ], args[1])
       assert_equal([ 'suffix 1 (optional)', :string, nil ], args[2])
@@ -852,7 +852,7 @@ module TestRucy
     end
 
     def test_new
-      doc = @factory.new('/', nil,
+      doc = @builder.new('/', nil,
 			 nil, nil,
 			 nil, nil,
 			 nil, nil,
