@@ -1,7 +1,8 @@
 #!/usr/local/bin/ruby
-# $Id: test_multi_process.rb,v 1.4 2004/10/02 01:00:22 toki Exp $
+# $Id: test_multi_process.rb,v 1.7 2004/12/11 14:33:11 toki Exp $
 
 require 'rubyunit'
+require 'forwarder'
 require 'socket'
 require 'sockutils'
 require 'pseudo_io'
@@ -77,12 +78,23 @@ module TestRucy
 
   class TestMultiProcessRestartSignal < RUNIT::TestCase
     def setup
+      # for Rucy::Server class
       @restart_call = 0
       @close_call = 0
+
+      @server = Forwarder.new(self)
+      class << @server
+	def_delegator :__getobj__, :restart
+	def_delegator :__getobj__, :close
+      end
+
+      # target
       @restart_signal = Rucy::MultiProcessRestartSignal.new
-      @restart_signal.server = self
+      @restart_signal.server = @server
     end
 
+    # for Rucy::Server class
+
     def restart
       @restart_call += 1
       nil
@@ -93,6 +105,8 @@ module TestRucy
       nil
     end
 
+    # test
+
     def test_notify_restart
       pid_list = Array.new
       begin
@@ -161,26 +175,6 @@ module TestRucy
   class TestMultiProcessMessenger < RUNIT::TestCase
     include SocketUtils
 
-    def messenger_threads
-      @messenger_threads_call += 1
-      4
-    end
-
-    def messenger_queue_length
-      @messenger_queue_length_call += 1
-      2
-    end
-
-    def subprocess_user
-      @subprocess_user_call += 1
-      'nobody'
-    end
-
-    def subprocess_group
-      @subprocess_group_call += 1
-      'nogroup'
-    end
-
     def setup
       @document = Rucy::Page.new("<html>Hello world.</html>\n")
       @log_pio = PseudoIO.new
@@ -188,23 +182,38 @@ module TestRucy
       @access_log = Rucy::AccessLog.new(PseudoIO.new, '')
       @messenger = Rucy::MultiProcessMessenger.new(@document, @logger, @access_log)
 
+      # for Rucy::Server class
       @messenger_threads_call = 0
       @messenger_queue_length_call = 0
-      @subprocess_user_call = 0
-      @subprocess_group_call = 0
+      @privilege_call = 0
+
+      @server = Forwarder.new(self)
+      class << @server
+	def_delegator :__getobj__, :messenger_threads
+	def_delegator :__getobj__, :messenger_queue_length
+	def_delegator :__getobj__, :privilege
+      end
+
+      # for Rucy::Privilege class
+      @privileged_user_call = 0
+      @cancel_privilege_call = 0
+
+      @privilege = Forwarder.new(self)
+      class << @privilege
+	def_delegator :__getobj__, :privileged_user?
+	def_delegator :__getobj__, :cancel_privilege
+      end
+
       assert_nil(@messenger.messenger_threads)
       assert_nil(@messenger.messenger_queue_length)
-      assert_nil(@messenger.subprocess_user)
-      assert_nil(@messenger.subprocess_group)
-      @messenger.open(self)
+      @messenger.open(@server)
       assert_equal(1, @messenger_threads_call)
       assert_equal(1, @messenger_queue_length_call)
-      assert_equal(1, @subprocess_user_call)
-      assert_equal(1, @subprocess_group_call)
+      assert_equal(1, @privilege_call)
+      #assert_equal(1, @privileged_user_call) # called in forked subprocess
+      #assert_equal(1, @cancel_privilege_call) # called in forked subprocess
       assert_equal(4, @messenger.messenger_threads)
       assert_equal(2, @messenger.messenger_queue_length)
-      assert_equal('nobody', @messenger.subprocess_user)
-      assert_equal('nogroup', @messenger.subprocess_group)
 
       @queue = Rucy::SocketQueue.new(2)
       @thread = Thread.new{
@@ -217,6 +226,37 @@ module TestRucy
       @thread.join
     end
 
+    # for Rucy::Server class
+
+    def messenger_threads
+      @messenger_threads_call += 1
+      4
+    end
+
+    def messenger_queue_length
+      @messenger_queue_length_call += 1
+      2
+    end
+
+    def privilege
+      @privilege_call += 1
+      @privilege
+    end
+
+    # for Rucy::Privilege class
+
+    def privileged_user?
+      @privileged_user_call += 1
+      true
+    end
+
+    def cancel_privilege
+      @cancel_privilege_call += 1
+      nil
+    end
+
+    # test
+
     def test_GET
       nconns = 16; nreqs = 4
       nconns.times do
@@ -257,23 +297,44 @@ module TestRucy
       #@log_io = File.open('test_multi_process_server.log', 'a')
       #@log_io.sync = true
       #@log_io.puts '<start>'
+
+      # for Rucy::Document class
+      @document_open_call = 0
+      @document_close_call = 0
+
+      @document = Forwarder.new(self)
+      class << @document
+	def_delegator :__getobj__, :open
+	def_delegator :__getobj__, :close
+	def_delegator :__getobj__, :each
+      end
+
+      # for Rucy::Privilege
+      @privileged_user_call = 0
+      @cancel_privilege_call = 0
+
+      @privilege = Forwarder.new(self)
+      class << @privilege
+	def_delegator :__getobj__, :privileged_user?
+	def_delegator :__getobj__, :cancel_privilege
+      end
+
       @restart_called = 0
       @server_open_call = 0
       @server_close_call = 0
-      @document_open_call = 0
-      @document_close_call = 0
       @server = Rucy::Server.new
-      @server.open_hook{ |s|
+      @server.open_hook{|s|
 	@server_open_call += 1
 	s.port = SERVER_PORT
+	s.privilege = @privilege
 	s.mount(Rucy::Page.new("<html>Hello world.</html>\n"), '/')
-	s.mount(self, '/test_document_open_close')
+	s.mount(@document, '/test_document_open_close')
 	s.messenger_factory = Rucy::MultiProcessMessenger
 	#logger = Rucy::Logger.new(@log_io)
 	#logger.log_debug = true
 	#s.add_logger(logger)
       }
-      @server.close_hook{ |s|
+      @server.close_hook{|s|
 	@server_close_call += 1
       }
       @svr_pid = fork{
@@ -295,6 +356,15 @@ module TestRucy
       sleep(0.1)
     end
 
+    def teardown
+      Process.kill(:USR1, @svr_pid)
+      Process.waitpid(@svr_pid)
+      #@log_io.puts '<end>'
+      #@log_io.close
+    end
+
+    # for Rucy::Document class
+
     def open
       @document_open_call += 1
       nil
@@ -306,17 +376,24 @@ module TestRucy
     end
 
     def each(traversed={})
-      yield(self)
+      yield(@document)
       nil
     end
 
-    def teardown
-      Process.kill(:USR1, @svr_pid)
-      Process.waitpid(@svr_pid)
-      #@log_io.puts '<end>'
-      #@log_io.close
+    # for Rucy::Privilege
+
+    def privileged_user?
+      @privileged_user_call += 1
+      true
     end
 
+    def cancel_privilege
+      @cancel_privilege_call += 1
+      nil
+    end
+
+    # test
+
     def test_restart
       @server.restart
       @restart_called += 1
@@ -335,7 +412,7 @@ module TestRucy
 	response = Rucy::Response.new
 	response.parse(socket)
 	assert_equal('HTTP/1.1 200 OK', response.line)
-	assert(! response.headers('Connection').find{ |v| v =~ /close/i })
+	assert(! response.headers('Connection').find{|v| v =~ /close/i })
 	assert_equal('26', response.header('Content-Length'))
 	assert_equal('text/html', response.header('Content-Type'))
 	assert_match(response.header('Date'), /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), \d{2} (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \d{4} \d{2}:\d{2}:\d{2} GMT$/)
@@ -376,7 +453,7 @@ module TestRucy
 	    response = Rucy::Response.new
 	    response.parse(socket)
 	    assert_equal('HTTP/1.1 200 OK', response.line)
-	    assert(! response.headers('Connection').find{ |v| v =~ /close/i })
+	    assert(! response.headers('Connection').find{|v| v =~ /close/i })
 	    assert_equal('26', response.header('Content-Length'))
 	    assert_equal('text/html', response.header('Content-Type'))
 	    assert_match(response.header('Date'), /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), \d{2} (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \d{4} \d{2}:\d{2}:\d{2} GMT$/)
@@ -443,14 +520,35 @@ module TestRucy
       #@log_io = File.open('test_multi_process_server.log', 'a')
       #@log_io.sync = true
       #@log_io.puts '<start>'
-      @server_open_call = 0
-      @server_close_call = 0
+
+      # for Rucy::Document class
       @document_open_call = 0
       @document_close_call = 0
+
+      @document = Forwarder.new(self)
+      class << @document
+	def_delegator :__getobj__, :open
+	def_delegator :__getobj__, :close
+	def_delegator :__getobj__, :each
+      end
+
+      # for Rucy::Privilege class
+      @privileged_user_call = 0
+      @cancel_privilege_call = 0
+
+      @privilege = Forwarder.new(self)
+      class << @privilege
+	def_delegator :__getobj__, :privileged_user?
+	def_delegator :__getobj__, :cancel_privilege
+      end
+
+      @server_open_call = 0
+      @server_close_call = 0
       @server = Rucy::Server.new
-      @server.open_hook{ |s|
+      @server.open_hook{|s|
 	@server_open_call += 1
 	s.port = SERVER_PORT
+	s.privilege = @privilege
 	s.mount(Rucy::Page.new("<html>Hello world.</html>\n"), '/')
 	s.mount(self, '/test_document_open_close')
 	s.messenger_factory = Rucy::MultiProcessMessenger
@@ -459,7 +557,7 @@ module TestRucy
 	#logger.log_debug = true
 	#s.add_logger(logger)
       }
-      @server.close_hook{ |s|
+      @server.close_hook{|s|
 	@server_close_call += 1
       }
       @svr_pid = fork{
@@ -481,6 +579,15 @@ module TestRucy
       sleep(0.1)
     end
 
+    def teardown
+      Process.kill(:USR1, @svr_pid)
+      Process.waitpid(@svr_pid)
+      #@log_io.puts '<end>'
+      #@log_io.close
+    end
+
+    # for Rucy::Document class
+
     def open
       @document_open_call += 1
       nil
@@ -496,13 +603,20 @@ module TestRucy
       nil
     end
 
-    def teardown
-      Process.kill(:USR1, @svr_pid)
-      Process.waitpid(@svr_pid)
-      #@log_io.puts '<end>'
-      #@log_io.close
+    # for Rucy::Privilege class
+
+    def privileged_user?
+      @privileged_user_call += 1
+      true
     end
 
+    def cancel_privilege
+      @cancel_privilege_call += 1
+      nil
+    end
+
+    # test
+
     def test_timeout
       socket = TCPSocket.new('localhost', SERVER_PORT)
       setsockopt(socket)
