@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test_redirect.rb,v 1.3 2004/09/29 15:14:01 toki Exp $
+# $Id: test_redirect.rb,v 1.5 2004/12/12 00:20:45 toki Exp $
 
 require 'rubyunit'
 require 'pseudo_req_res'
@@ -22,7 +22,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -36,7 +36,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(307, @messg_head.status)
       assert_equal('Temporary Redirect', @messg_head.reason)
@@ -50,7 +50,7 @@ module TestRucy
       @request.method = 'HEAD'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -66,7 +66,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	redirect.publish('', @request, @response, self)
+	redirect.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(405, $!.status) #  Method Not Allowed
 	assert_equal('GET, HEAD', $!.header('Allow'))
@@ -81,7 +81,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -91,24 +91,24 @@ module TestRucy
     end
   end
 
-  class TestRedirectDocumentFactory < RUNIT::TestCase
+  class TestRedirectDocumentBuilder < RUNIT::TestCase
     def setup
       @loader = Rucy::SimpleLoader.new
       @loader.load('../mod_docs/redirect.rb')
-      @RedirectDocumentFactory = @loader.const_get('RedirectDocumentFactory')
-      @factory = @RedirectDocumentFactory.instance
+      @RedirectDocumentBuilder = @loader.const_get('RedirectDocumentBuilder')
+      @builder = @RedirectDocumentBuilder.instance
     end
 
     def test_set_doc_option
-      @factory.set_doc_option(Hash.new)
+      @builder.set_doc_option(Hash.new)
     end
 
     def test_doc_name
-      assert_equal('Redirect', @factory.doc_name)
+      assert_equal('Redirect', @builder.doc_name)
     end
 
     def test_doc_args
-      args = @factory.doc_args
+      args = @builder.doc_args
       assert_equal([ 'location', :string, nil ], args[0])
       assert_equal([ 'status', :select, [
 		       '302 Found',
@@ -120,7 +120,7 @@ module TestRucy
     end
 
     def test_new
-      doc = @factory.new('/foo', '302 Found')
+      doc = @builder.new('/foo', '302 Found')
       assert_instance_of(@loader.const_get('RedirectDocument'), doc)
     end
   end
@@ -141,7 +141,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -155,7 +155,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/foo/bar/baz'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -170,7 +170,7 @@ module TestRucy
       @request.path = '/foo/bar/baz'
       @request.query = 'alpha=1&beta=2'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -184,7 +184,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(307, @messg_head.status)
       assert_equal('Temporary Redirect', @messg_head.reason)
@@ -198,7 +198,7 @@ module TestRucy
       @request.method = 'HEAD'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -214,7 +214,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	redirect.publish('', @request, @response, self)
+	redirect.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(404, $!.status) # Not Found
 	done = true
@@ -230,7 +230,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	redirect.publish('', @request, @response, self)
+	redirect.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(405, $!.status) # Method Not Allowed
 	assert_equal('GET, HEAD', $!.header('Allow'))
@@ -245,7 +245,7 @@ module TestRucy
       @request.method = 'GET'
       @request.path = '/foo/bar'
       @request.version = 'HTTP/1.1'
-      redirect.publish('', @request, @response, self)
+      redirect.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(302, @messg_head.status)
       assert_equal('Found', @messg_head.reason)
@@ -255,24 +255,24 @@ module TestRucy
     end
   end
 
-  class TestRegexpRedirectDocumentFactory < RUNIT::TestCase
+  class TestRegexpRedirectDocumentBuilder < RUNIT::TestCase
     def setup
       @loader = Rucy::SimpleLoader.new
       @loader.load('../mod_docs/redirect.rb')
-      @RegexpRedirectDocumentFactory = @loader.const_get('RegexpRedirectDocumentFactory')
-      @factory = @RegexpRedirectDocumentFactory.instance
+      @RegexpRedirectDocumentBuilder = @loader.const_get('RegexpRedirectDocumentBuilder')
+      @builder = @RegexpRedirectDocumentBuilder.instance
     end
 
     def test_set_doc_option
-      @factory.set_doc_option(Hash.new)
+      @builder.set_doc_option(Hash.new)
     end
 
     def test_doc_name
-      assert_equal('RegexpRedirect', @factory.doc_name)
+      assert_equal('RegexpRedirect', @builder.doc_name)
     end
 
     def test_doc_args
-      args = @factory.doc_args
+      args = @builder.doc_args
       assert_equal([ 'request path pattern (regexp)', :regexp, nil ], args[0])
       assert_equal([ %q"replace location (usable \&, \0, \1 ... \9, \`, \', \+)", :string, nil ], args[1])
       assert_equal([ 'status', :select, [
@@ -285,7 +285,7 @@ module TestRucy
     end
 
     def test_new
-      doc = @factory.new(%r'/foo(.*?)\.html$', '\`/bar\1.html', '302 Found')
+      doc = @builder.new(%r'/foo(.*?)\.html$', '\`/bar\1.html', '302 Found')
       assert_instance_of(@loader.const_get('RegexpRedirectDocument'), doc)
     end
   end
