@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test_sample.rb,v 1.2 2004/09/28 17:04:47 toki Exp $
+# $Id: test_sample.rb,v 1.3 2004/12/12 00:20:47 toki Exp $
 
 require 'rubyunit'
 require 'pseudo_req_res'
@@ -34,7 +34,7 @@ module TestRucy
       @request.method ='GET'
       @request.uri = '/'
       @request.version = 'HTTP/1.1'
-      @sample.publish('', @request, @response, self)
+      @sample.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -48,7 +48,7 @@ module TestRucy
       @request.method ='HEAD'
       @request.uri = '/'
       @request.version = 'HTTP/1.1'
-      @sample.publish('', @request, @response, self)
+      @sample.publish('', @request, @response, @logger)
       assert_equal('HTTP/1.1', @messg_head.version)
       assert_equal(200, @messg_head.status)
       assert_equal('OK', @messg_head.reason)
@@ -64,7 +64,7 @@ module TestRucy
       @request.version = 'HTTP/1.1'
       done = false
       begin
-	@sample.publish('', @request, @response, self)
+	@sample.publish('', @request, @response, @logger)
       rescue Rucy::HTTPError
 	assert_equal(405, $!.status) # Method Not Allowd
 	done = true
@@ -96,7 +96,7 @@ module TestRucy
 					   'foo', # radio
 					   { 'foo' => true, 'bar' => false, 'baz' => false } # checkset
 					   )
-      @doc = Rucy::FilterDocument.new(self, @sample)
+      @doc = Rucy::FilterDocument.new(@document, @sample)
     end
 
     def test_GET
