@@ -1,7 +1,8 @@
 #!/usr/local/bin/ruby
-# $Id: test_server.rb,v 1.4 2004/10/02 01:00:25 toki Exp $
+# $Id: test_server.rb,v 1.5 2004/12/11 12:07:49 toki Exp $
 
 require 'rubyunit'
+require 'forwarder'
 require 'thread'
 require 'socket'
 require 'sockutils'
@@ -19,23 +20,32 @@ module TestRucy
     SERVER_PORT = 9876
 
     def setup
+      # for Rucy::Document class
+      @document_open_call = 0
+      @document_close_call = 0
+
+      @document = Forwarder.new(self)
+      class << @document
+	def_delegator :__getobj__, :open
+	def_delegator :__getobj__, :close
+	def_delegator :__getobj__, :each
+      end
+
       @restart_called = 0
       @server_open_call = 0
       @server_close_call = 0
-      @document_open_call = 0
-      @document_close_call = 0
       @server = Rucy::Server.new
-      @server.open_hook{ |s|
+      @server.open_hook{|s|
 	@server_open_call += 1
 	s.bind_address = 'localhost'
 	s.port = SERVER_PORT
 	s.mount(Rucy::Page.new("<html>Hello world.</html>\n"), '/')
-	s.mount(self, '/test_document_open_close')
+	s.mount(@document, '/test_document_open_close')
 	# logger = Rucy::Logger.new(STDERR)
 	# logger.log_debug = true
 	# s.add_logger(logger)
       }
-      @server.close_hook{ |s|
+      @server.close_hook{|s|
 	@server_close_call += 1
       }
       @thread = Thread.new{
@@ -44,6 +54,17 @@ module TestRucy
       sleep(0.1)
     end
 
+    def teardown
+      @server.close
+      @thread.join
+      assert_equal(1 + @restart_called, @server_open_call)
+      assert_equal(1 + @restart_called, @server_close_call)
+      assert_equal(1 + @restart_called, @document_open_call)
+      assert_equal(1 + @restart_called, @document_close_call)
+    end
+
+    # for Rucy::Document class
+
     def open
       @document_open_call += 1
       nil
@@ -55,18 +76,11 @@ module TestRucy
     end
 
     def each(traversed={})
-      yield(self)
+      yield(@document)
       nil
     end
 
-    def teardown
-      @server.close
-      @thread.join
-      assert_equal(1 + @restart_called, @server_open_call)
-      assert_equal(1 + @restart_called, @server_close_call)
-      assert_equal(1 + @restart_called, @document_open_call)
-      assert_equal(1 + @restart_called, @document_close_call)
-    end
+    # test
 
     def test_restart
       @server.restart
@@ -86,7 +100,7 @@ module TestRucy
 	response = Rucy::Response.new
 	response.parse(socket)
 	assert_equal('HTTP/1.1 200 OK', response.line)
-	assert(! response.headers('Connection').find{ |v| v =~ /close/i })
+	assert(! response.headers('Connection').find{|v| v =~ /close/i })
 	assert_equal('26', response.header('Content-Length'))
 	assert_equal('text/html', response.header('Content-Type'))
 	assert_match(response.header('Date'), /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), \d{2} (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \d{4} \d{2}:\d{2}:\d{2} GMT$/)
@@ -127,7 +141,7 @@ module TestRucy
 	    response = Rucy::Response.new
 	    response.parse(socket)
 	    assert_equal('HTTP/1.1 200 OK', response.line)
-	    assert(! response.headers('Connection').find{ |v| v =~ /close/i })
+	    assert(! response.headers('Connection').find{|v| v =~ /close/i })
 	    assert_equal('26', response.header('Content-Length'))
 	    assert_equal('text/html', response.header('Content-Type'))
 	    assert_match(response.header('Date'), /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), \d{2} (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \d{4} \d{2}:\d{2}:\d{2} GMT$/)
@@ -191,23 +205,32 @@ module TestRucy
     SERVER_PORT = 9876
 
     def setup
-      @server_open_call = 0
-      @server_close_call = 0
+      # for Rucy::Document class
       @document_open_call = 0
       @document_close_call = 0
+
+      @document = Forwarder.new(self)
+      class << @document
+	def_delegator :__getobj__, :open
+	def_delegator :__getobj__, :close
+	def_delegator :__getobj__, :each
+      end
+
+      @server_open_call = 0
+      @server_close_call = 0
       @server = Rucy::Server.new
-      @server.open_hook{ |s|
+      @server.open_hook{|s|
 	@server_open_call += 1
 	s.bind_address = 'localhost'
 	s.port = SERVER_PORT
 	s.timeout = 0.01	# short timeout for test
 	s.mount(Rucy::Page.new("<html>Hello world.</html>\n"), '/')
-	s.mount(self, '/test_document_open_close')
+	s.mount(@document, '/test_document_open_close')
 	# logger = Rucy::Logger.new(STDERR)
 	# logger.log_debug = true
 	# s.add_logger(logger)
       }
-      @server.close_hook{ |s|
+      @server.close_hook{|s|
 	@server_close_call += 1
       }
       @thread = Thread.new{
@@ -216,6 +239,17 @@ module TestRucy
       sleep(0.1)
     end
 
+    def teardown
+      @server.close
+      @thread.join
+      assert_equal(1, @server_open_call)
+      assert_equal(1, @server_close_call)
+      assert_equal(1, @document_open_call)
+      assert_equal(1, @document_close_call)
+    end
+
+    # for Rucy::Document class
+
     def open
       @document_open_call += 1
       nil
@@ -227,18 +261,11 @@ module TestRucy
     end
 
     def each(traversed={})
-      yield(self)
+      yield(@document)
       nil
     end
 
-    def teardown
-      @server.close
-      @thread.join
-      assert_equal(1, @server_open_call)
-      assert_equal(1, @server_close_call)
-      assert_equal(1, @document_open_call)
-      assert_equal(1, @document_close_call)
-    end
+    # test
 
     def test_timeout
       socket = TCPSocket.new('localhost', SERVER_PORT)
